﻿* Encoding: windows-1252.
* MICS6 SR.11.2.

** Children age 0-17 years with at least one parent living elsewhere: HL15=1, 2, 3, or 4 or HL19=1, 2, 3, or 4.

** Children age 0-17 years with at least one parent living abroad: HL15=1 or HL19=1.

***.

include "surveyname.sps".

get file="hl.sav".

sort cases by hh1 hh2 hl1.

* select children 0-17 listed in the HL.
select if (HL6 <= 17) .

* weight data by household weight.
weight by hhweight.

* Calculate child's orphanhood status.
compute oStatus = 9.
if (HL12 = 1 and HL16 = 1) oStatus = 1.
if (HL12 = 1 and HL16 = 2) oStatus = 2.
if (HL12 = 2 and HL16 = 1) oStatus = 3.
if (HL12 = 2 and HL16 = 2) oStatus = 4.
if (HL12 >=8 or HL16 >= 8) oStatus = 9.
variable labels oStatus "Orphanhood status".
value labels oStatus
1 "Both parents alive"
2 "Only mother alive"
3 "Only father alive"
4 "Both parents deceased"
9 "Unknown".

if ((HL15 = 1 or HL15 = 2 or HL15 = 3 or HL15 = 4) and HL17 = 1) pElse = 1 .
if (HL13 = 1 and (HL19 = 1 or HL19 = 2 or HL19 = 3 or HL19 = 4)) pElse = 2 .
if ((HL15 = 1 or HL15 = 2 or HL15 = 3 or HL15 = 4) and (HL19 = 1 or HL19 = 2 or HL19 = 3 or HL19 = 4)) pElse = 3.
variable labels pElse " ".
value labels pElse 
1 "Only mother is living elsewhere [A]"
2 "Only father is living elsewhere [A]"
3 "Both mother and father are living elsewhere [A]".

compute anyElse = 0 .
if (pElse = 1 or pElse = 2 or pElse = 3) anyElse = 100.

if (HL15 = 1 and HL17 = 1) pAbroad = 1.
if (HL13 = 1 and HL19 = 1) pAbroad = 2.
if (HL15 = 1 and HL19 = 1) pAbroad = 3.
value labels pAbroad
  1 "Only mother living abroad"
  2 "Only father living abroad"
  3 "Both mother and father living abroad".

compute anyAbroad = 0.
if (pAbroad = 1 or pAbroad = 2 or pAbroad = 3) anyAbroad = 100.

variable labels
   anyElse "At least one parent living elsewhere [A]"
  /anyAbroad   "At least one parent living abroad [1]" .
  
compute numChildren = 1.
value labels numChildren 1 "Number of children age 0-17 years" .

compute layer = 0.
variable labels layer "".
value labels layer 0 "Percentage of children age 0-17 years with:".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

recode HL6
  ( 0 thru  4 = 1)
  ( 5 thru  9 = 2)
  (10 thru 14 = 3)
  (15 thru 17 = 4) into ageGroups .
variable labels ageGroups "Age".
value labels ageGroups
  1 "0-4"
  2 "5-9"
  3 "10-14"
  4 "15-17" .
  
* For labels in French uncomment commands below.
* variable labels
      oStatus "Statut d'orphelin"
	 /anyElse "Au moins un parent vivant ailleurs [A]"
     /anyAbroad   "Au moins un parent vivant à l'étranger [1]".
* value labels 
      numChildren 1 "Nombre d'enfants âgés de 0 à 17 ans"
	 /layer 0 "Pourcentage d'enfants âgés de 0 à 17 ans avec:"
	 /labels pElse 
  1 "Seule la mère vit ailleurs [A]"
  2 "Seul le père vit ailleurs [A]"
  3 "La mère et le père vivent ailleurs [A]"
	 /pAbroad
  1 "Seule la mère vivant à l'étranger"
  2 "Seul le père vivant à l'étranger"
  3 "La mère et le père vivant à l'étranger"
     /oStatus
  1 "Deux parents en vie"
  2 "Seulement la mère en vie"
  3 "Seulement le père en vie"
  4 "Deux parents sont décédés"
  9 "Pas d'information".

    
* For labels in Spanish uncomment commands below.
* variable labels
      ageGroups "Edad"
	 /oStatus "Estatus de orfandad"
	 /anyElse "Al menos uno de los padre vive en otra parte [A]"
     /anyAbroad   "Al menos un padre vive en el extranjero [1]".
* value labels 
      numChildren 1 "Número de niños de 0-17 años"
	 /layer 0 "Porcentaje de niños de 0-17 años con:"
	 /labels pElse 
  1 "Sólo la madre vive en otra parte [A]"
  2 "Sólo el padre vive en otra parte [A]"
  3 "Ambos, la madre y el padre viven en otra parte [A]"
	 /pAbroad
  1 "Solo la madre vive en el extranjero"
  2 "Solo el padre vive en el extranjero"
  3 "Ambos padres viven en el extranjero"
     /oStatus
  1 "Ambos padres vivos"
  2 "Sólo la madre viva"
  3 "Sólo el padre vivo"
  4 "Ambos padres fallecidos"
  9 "Ignorado".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables =  numChildren layer pElse pAbroad
           display = none
  /table  total [c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + ageGroups [c]
        + oStatus [c]
        + ethnicity [c]
        + windex5 [c]
   by
         layer [c] > ( pElse[c] [rowpct.totaln '' f5.1] 
        + anyElse [s] [mean, '', f5.1]
        + pAbroad [c] [rowpct.totaln '' f5.1] 
        + anyAbroad [s] [mean, '', f5.1])
        + numChildren [c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Table SR.11.2: Children's living arrangements and co-residence with parents"
  	 "Percentage of children age 0-17 years by co-residence of parents, " + surveyname
   caption=
     "[1] MICS indicator SR.20 - Children with at least one parent living abroad"
     "[A] Includes parents living abroad as well as those living elsewhere in the country"
  .

* Ctables command in French.
* ctables
  /vlabels variables =  numChildren layer pElse pAbroad
           display = none
  /table  total [c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + ageGroups [c]
        + oStatus [c]
        + ethnicity [c]
        + windex5 [c]
   by
         layer [c] > ( pElse[c] [rowpct.totaln '' f5.1] 
        + anyElse [s] [mean, '', f5.1]
        + pAbroad [c] [rowpct.totaln '' f5.1] 
        + anyAbroad [s] [mean, '', f5.1])
        + numChildren [c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tableau SR.11.2: Arrangements de vie des enfants et orphelins and co-résidence avec les parents "
  	 "Pourcentage d'enfants âgés de 0 à 17 ans selon la co-residence des parents, " + surveyname
   caption=
     "[1]  Indicateur MICS SR.20 - Enfants avec au moins un parent vivant à l'étranger"
     "[A]  Comprend les parents vivant à l'étranger ainsi que ceux qui vivent ailleurs au pays"
  .
  
* Ctables command in Spanish.
* ctables
  /vlabels variables =  numChildren layer pElse pAbroad
           display = none
  /table  total [c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + ageGroups [c]
        + oStatus [c]
        + ethnicity [c]
        + windex5 [c]
   by
         layer [c] > ( pElse[c] [rowpct.totaln '' f5.1] 
        + anyElse [s] [mean, '', f5.1]
        + pAbroad [c] [rowpct.totaln '' f5.1] 
        + anyAbroad [s] [mean, '', f5.1])
        + numChildren [c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tabla SR.11.2: Entorno familiar de los niños/as y co-residencia con los padres "
  	 "Porcentaje de niños de 0-17 años según co-residencia de los padres, " + surveyname
   caption=
     "[1]  Indicador MICS SR.20 - Niños con al menos uno de los padres viviendo en el extranjero"
     "[A]  Incluye los padre que viven en el extranjero o en cualquier otro lugar del país"
  .
  
new file.