﻿* Encoding: windows-1252.
* MICS6 SR.5.1W.

* v01 - 2017-09-21.

** Total weighted and unweighted numbers of women should be equal when normalized sample weights are used.


***.

* Call include file for the working directory and the survey name.
include "surveyname.sps".

* Open women data file.
get file = 'wm.sav'.

include "CommonVarsWM.sps".

* Select only interviewed women.
select if (WM17 = 1).

* Weight the data by the women weight.
weight by wmweight.

* Create marital status with separate groups for formerly married.
do if (MA1 = 1 or MA1 = 2).
+ compute mstatus1 = 1.
else if (MA5 = 1 or MA5 = 2).
+ compute mstatus1 = MA6+1.
+ if (MA6 = 9) mstatus1 = 9.
else if (MA5 = 3).
+ compute mstatus1 = 5.
else.
+ compute mstatus1 = 9.
end if.
variable labels mstatus1 "Marital/Union status".
value labels mstatus1
    1 "Currently married/in union"
    2 "Widowed"
    3 "Divorced"
    4 "Separated"
    5 "Never married/in union"
    9 "Missing".

* Rename question cm1 and rename value labels.
recode CM1 (1 = 2) (9 = 29) (else = 1) into everbirth.
if (CM1 = 2 and CM8 = 1) everbirth = 2.

* Recode births in last 2 years.
if (cm17 = 1) bl2y = 21.
if (cm17 = 0 and everbirth = 2) bl2y = 22.

value labels everbirth
   1 "Never gave birth"
   2 "Ever gave birth"
  21 "   Gave birth in last two years"
  22 "   No birth in last two years"
  29 "   Missing".

* Define Multiple Response Sets.
mrsets
  /mcgroup name = $mrb
           label = 'Motherhood and recent births'
           variables = everbirth bl2y.

* labels in French.
*mrsets
  /mcgroup name = $mrb
           label = 'Statut de maternité'
           variables = everbirth bl2y.
		   
* labels in Spanish.
*mrsets
  /mcgroup name = $mrb
           label = 'Maternidad y nacimientos recientes'
           variables = everbirth bl2y.

compute total = 1.
variable labels total "Total".
value labels total 1" ".

compute wp = 0.
variable labels wp " ".
compute nwm = 0.
variable labels nwm "Number of women".

* Labels in French.
 * variable labels mstatus1 "Situation de famille/Union".
 * value labels mstatus1
    1 "Mariée actuellement/vit avec un homme"
    2 "Veuve"
    3 "Divorcée"
    4 "Séparée"
    5 "Jamais mariée/vécu avec un homme"
    9 "Manquant".

 * value labels everbirth
   1 "N'a jamais mis au monde"
   2 "A déjà mis au monde"
  21 "   A eu une naissance dans les 2 dernières années"
  22 "   Pas de naissance dans les 2 dernières années"
  29 "   Manquant".

 * variable labels nwm "Nombre de femmes".
 
* Labels in Spanish.
 * variable labels mstatus1 "Estado de matrimonio/unión".
 * value labels mstatus1
    1 "Actualmente casada/en unión"
    2 "Viuda"
    3 "Divorciada"
    4 "Separada"
    5 "Nunca casada/en unión"
    9 "Ignorado".

 * value labels everbirth
   1 "Nunca dio a luz"
   2 "Alguna vez dio a luz"
  21 "   Dio a luz en los últimos dos años"
  22 "   Sin nacimientos en los últimos dos años"
  29 "   Ignorado".

 * variable labels nwm "Número de mujeres".


* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = wp display = none
  /table   total [c]
         + hh6 [c]
         + hh7 [c]
         + $wage [c]
         + welevel [c]
         + mstatus1 [c]
         + $mrb [c]
         + insurance [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]
   by
           wp [s] [colpct.count,'Weighted percent',f5.1]
         + nwm [s] [count,'Weighted', f5.0, 
                    ucount, 'Unweighted', f5.0]
  /categories variables=all empty=exclude missing=exclude
  /titles title=
    "Table SR.5.1W: Women's background characteristics"
    "Percent and frequency distribution of women age 15-49 years by selected background characteristics, " + surveyname
  .


* Ctables command in French.
*
ctables
  /vlabels variables = wp display = none
  /table   total [c]
         + hh6 [c]
         + hh7 [c]
         + $wage [c]
         + welevel [c]
         + mstatus1 [c]
         + $mrb [c]
         + insurance [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]
   by
           wp [s] [colpct.count,'Pourcentage pondéré',f5.1]
         + nwm [s] [count,'Pondéré', f5.0, 
                    ucount, 'Non pondéré', f5.0]
  /categories variables=all empty=exclude missing=exclude
  /titles title=
    "Tableau SR.5.1W: Caractéristiques de base des femmes"
    "Distribution en pourcentage et fréquence des femmes âgées de 15-49 ans selon les caractéristiques de base sélectionnées, " + surveyname
  .

* Ctables command in Spanish.
*
ctables
  /vlabels variables = wp display = none
  /table   total [c]
         + hh6 [c]
         + hh7 [c]
         + $wage [c]
         + welevel [c]
         + mstatus1 [c]
         + $mrb [c]
         + insurance [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]
   by
           wp [s] [colpct.count,'Porcentaje ponderado',f5.1]
         + nwm [s] [count,'Ponderado', f5.0, 
                    ucount, 'Sin ponderar', f5.0]
  /categories variables=all empty=exclude missing=exclude
  /titles title=
    "Tabla SR.5.1W: Características básicas de las mujeres"
    "Distribución porcentual y frecuencial de mujeres de 15-49 años por características básicas seleccionadas, " + surveyname
  .


new file.
