* Encoding: windows-1252.
* MICS6 SR.6.1M.

* v01 - 2017-09-22.

** Respondents are distributed according to the highest level of school attended (MWB6U) and further by the results of reading a short simple statement about everyday life (MWB14).

** Those who attended secondary or higher education (MWB6U=2, 3 or 4) are classified as literate, as they are assumed literate due to their education level and are therefore not asked to read the statement. 
** All others who successfully read the statement (MWB14=3) are also classified as literate. 

** The percent missing includes those for whom no sentence in the required language was available (MWB14=6) or for whom no response was reported. 
** If exceeding 10 percent in any category, caution should be exercised in the interpretation of the results. Additionally, a low response rate may be observed among certain age groups. 
** Particularly, if the response rate of age group 15-24 years is below 95 percent, the data obtained through the Education module should be examined. 
** In some countries, low response rates for this age group is due to boarding at secondary or higher education, in which case a large number of lost respondents would have been classified as literate had they been interviewed.


***.


include "surveyname.sps".

get file = 'mn.sav'.

include "CommonVarsMN.sps".

select if (MWM17 = 1).

weight by mnweight.

compute literate  = 2.
if (MWB6A >= 2 and MWB6A < 8) literate = 1. 
if (MWB14 = 3) literate = 1.
variable labels literate " ".
value labels literate 1 "Literate" 2 "Illiterate".

compute literateP = 0.
if (literate = 1) literateP = 100. 
variable labels literateP "Total percentage literate [1]".

compute layer = 0.
variable labels layer " ".
value labels layer 0 "Percent distribution of highest level attended and literacy".

* add A to welevel label.
add value labels mwelevel 3 "Secondary or higher [A]".

compute numMen = 1.
variable labels numMen "Number of men age 15-49 years".
value labels numMen 1 "".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

compute tot = 100.
variable labels tot "Total".
value labels tot 100 " ".

* Labels in French.
 * value labels literate 1 "Alphabtise" 2 "Analphabte".
 * variable labels literateP "Pourcentage total des hommes Alphabtises [1]".
 * value labels layer 0 "Percent distribution of highest level attended and literacy".
 * add value labels mwelevel 3 "Secondaire et ou Suprieur [A]".
 * variable labels numMen "Nombre de hommes gs 15-49 ans".

* Labels in Spanish.
 * value labels literate 1 "Alfabetizados" 2 "Analfabetos".
 * variable labels literateP "Porcentaje total alfabetizados [1]".
 * value labels layer 0 "Distribucin porcentual del nivel ms alto asistido y alfabetizacin".
 * add value labels mwelevel 3 "Secundaria o superior [A]".
 * variable labels numMen "Nombre de hommes gs 15-49 ans".
 
* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = layer mwelevel literate display = none
  /table   total[c]
         + hh6 [c]
         + hh7 [c]
         + $mage [c]
         + mdisability [c]
         + ethnicity[c]
         + windex5 [c]
   by
           layer [c] > mwelevel [c] > literate [c] [layerrowpct.validn '' f5.1] + tot [s] [mean '' f5.1] +
           literateP [s] [mean '' f5.1]
         + numMen[s][sum '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
    "Table SR.6.1M: Literacy (men)"
    "Percent distribution of men age 15-49 years by highest level of school attended and literacy, and the total percentage literate, " + surveyname
   caption =
    "[1] MICS indicator SR.2 - Literacy rate (age 15-24 years)"
    "[A] Respondents who have attended secondary school or higher are considered literate and are not tested."
  .

* Ctables command in French.
*
ctables
  /vlabels variables = layer mwelevel literate display = none
  /table   total[c]
         + hh6 [c]
         + hh7 [c]
         + $age [c]
         + mdisability [c]
         + ethnicity[c]
         + windex5 [c]
   by
           layer [c] > mwelevel [c] > literate [c] [layerrowpct.validn '' f5.1] + tot [s] [mean '' f5.1] +
           literateP [s] [mean '' f5.1]
         + numMen[s][sum '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
    "Tableau SR.6.1M: Alphabtisation (Hommes)"
    "Rpartition en pourcentage des hommes gs de 15  49 ans selon le plus haut niveau de scolarit atteint et l'alphabtisation, et le pourcentage total d'alphabtes, " + surveyname
   caption =
    "[1] Indicateur MICS ou SR.2 - Taux d'alphabtisation (ge 15-24 ans)"
    "[A] Les rpondants qui ont frquent l'cole secondaire ou suprieur sont considrs comme alphabtes et ne sont pas tests."
  .	

* Ctables command in Spanish.
*
ctables
  /vlabels variables = layer mwelevel literate display = none
  /table   total[c]
         + hh6 [c]
         + hh7 [c]
         + $age [c]
         + mdisability [c]
         + ethnicity[c]
         + windex5 [c]
   by
           layer [c] > mwelevel [c] > literate [c] [layerrowpct.validn '' f5.1] + tot [s] [mean '' f5.1] +
           literateP [s] [mean '' f5.1]
         + numMen[s][sum '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
    "Tabla SR.6.1M: Alfabetizacin (hombres)"
    "Porcentaje de hombres de 15-49 aos segn el nivel ms alto de educacin al que asisti y alfabetizacin, y porciento total alfabetizados, " + surveyname
   caption =
    "[1] Indicador MICS SR.2 - Tasa de alfabetizacin (15-24 aos)"
    "[A] Los respondientes que has asistido a la secundaria u otro nivel superior se consideran alfabetizados y no se les hace la prueba."
  .	

new file.
