﻿* Encoding: windows-1252.
* MICS6 SR.9.1W.

* v01 - 2017-09-22.

** Women who are exposed to all three media at least once a week are:
(MT1=1 or 2) and (MT2=1 or 2) and (MT3=1 or 2).

** Women exposed to any media at least once a week are: (MT1=1 or 2) or (MT2=1 or 2) or (MT3=1 or 2).

** Note that the percentages in the table do not add to 100.


***.

* Call include file for the working directory and the survey name.
include "surveyname.sps".

* Open women dataset.
get file = 'wm.sav'.

include "CommonVarsWM.sps".

* Select completed interviews.
select if (WM17 = 1).

* Weight the data by the women weight.
weight by wmweight.

* Generate numWomen variable.
compute numWomen = 1.
variable labels numWomen "".
value labels numWomen 1 "Number of women age 15-49 years".

* Generate indicators.
recode MT1 (2,3 = 100) (else = 0) into read1w.
variable labels read1w "Read a newspaper at least once a week".

recode MT2 (2,3 = 100) (else = 0) into listen1w.
variable labels listen1w "Listen to the radio at least once a week".

recode MT3 (2,3 = 100) (else = 0) into watch1w.
variable labels watch1w "Watch television at least once a week".

* Women who are exposed to all three media at least once a week are:.
* (MT1=1 or 2) and (MT2=1 or 2) and (MT3=1 or 2).
compute three = 0.
if (read1w = 100 and listen1w = 100 and watch1w = 100) three = 100.
variable labels three "All three media at least once a week [1]".

* Women exposed to any media at least once a week are: (MT1=1 or 2) or (MT2=1 or 2) or (MT3=1 or 2).
compute any1w = 0.
if (read1w = 100 or listen1w = 100 or watch1w = 100) any1w = 100.
variable labels any1w "Any media at least once a week".

compute layer0 = 0.
variable labels layer0 "".
value labels layer0 0 "Percentage of women age 15-49 who:".

compute total = 1.
variable labels total "".
value labels total 1 "Total".

* Labels in French.
 * value labels numWomen 1 "Nombre de femmes âgées de 15 à 49 ans".
 * variable labels read1w "Lisent un journal/magazine au moins une fois par semaine".
 * variable labels listen1w "Ecoutent la radio au moins une fois par semaine".
 * variable labels watch1w "Regardent la télévision au moins une fois par semaine".
 * variable labels three "Tous les trois média au moins une fois par semaine [1]".
 * variable labels any1w "N'importe quel media au moins une fois par semaine".
 * value labels layer0 0 "Pourcentage de femmes de 15-49 ans qui :".

* Labels in Spanish.
 * value labels numMen 1 "Número de mujeres de 15-49 años".
 * variable labels read1w "Leen un periódico al menos una vez a la semana".
 * variable labels listen1w "Escuchan la radio al menos una vez a la semana".
 * variable labels watch1w "Ven televisión al menos una vez a la semana".
 * variable labels three "Los tres medios al menos una vez a la semana [1]".
 * variable labels any1w "Algún medio al menos una vez a la semana".
 * value labels layer0 0 "Porcentaje de mujeres de 15-49 años que:".
 
ctables
  /vlabels variables =  numWomen layer0 total
         display = none
  /table  total [c]
        + hh6 [c]
        + hh7 [c]
        + $wage [c]
        + welevel [c]
        + disability [c]
        + ethnicity [c]
        + windex5 [c]
   by
          layer0 [c] > ( read1w [s] [mean '' f5.1]
                       + listen1w [s] [mean '' f5.1]
                       + watch1w [s] [mean '' f5.1])
        + three[s] [mean '' f5.1]
        + any1w[s] [mean '' f5.1]
        + numWomen[c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Table SR.9.1W: Exposure to mass media (women)"
     "Percentage of women age 15-49 years who are exposed to specific mass media on a weekly basis, " + surveyname
   caption =
     "[1] MICS indicator SR.3 - Exposure to mass media".

* Ctables in French.
* 
ctables
  /vlabels variables =  numWomen layer0 total
         display = none
  /table  total [c]
        + hh6 [c]
        + hh7 [c]
        + $wage [c]
        + welevel [c]
        + disability [c]
        + ethnicity [c]
        + windex5 [c]
   by
          layer0 [c] > ( read1w [s] [mean '' f5.1]
                       + listen1w [s] [mean '' f5.1]
                       + watch1w [s] [mean '' f5.1])
        + three[s] [mean '' f5.1]
        + any1w[s] [mean '' f5.1]
        + numWomen[c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tableau SR.9.1W: Exposition aux mass media (femmes)"
     "Pourcentage de femmes de 15-49 ans qui sont exposées à des média specifiques, de façon hebdomadaire, " + surveyname
   caption =
     "[1] Indicateur MICS SR.3 - Exposition aux mass media".
						
* Ctables in Spanish.
* 
ctables
  /vlabels variables =  numWomen layer0 total
         display = none
  /table  total [c]
        + hh6 [c]
        + hh7 [c]
        + $wage [c]
        + welevel [c]
        + disability [c]
        + ethnicity [c]
        + windex5 [c]
   by
          layer0 [c] > ( read1w [s] [mean '' f5.1]
                       + listen1w [s] [mean '' f5.1]
                       + watch1w [s] [mean '' f5.1])
        + three[s] [mean '' f5.1]
        + any1w[s] [mean '' f5.1]
        + numWomen[c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tabla SR.9.1W: Exposición a los medios de comunicación (mujeres)"
     "PPorcentaje de mujeres de 15-49 años que están expuestas a medios de comunicación específicos semanalmente, " + surveyname
   caption =
     "[1]  Indicador MICS SR.3 -  Exposición a los medios masivos de comunicación".
new file.
