﻿* Encoding: windows-1252.
* MICS6 SR.9.3M.

* v01 - 2017-09-22.

** The table consists of three panels, one for each of computer, mobile phone and internet use.

** Respondents who have ever used a computer are those responding yes to MT4. Those that used in the last 3 months are those responding 1, 2 or 3 in MT5 and those using at least once a week are MT5=2 or 3.

** Ownership of mobile phone: MT11=1. Similar to current use of computers, the use of mobile phone in the last 3 months is MT12=1, 2 or 3 and those using at least weekly are MT12=2 or 3.

** Ever use of internet is MT9=1 or MT6[C]=1 or MT6[F]=1. Similar to above, the current use is captured through MT10.


***.

* Call include file for the working directory and the survey name.
include "surveyname.sps".

* Open men dataset.
get file = 'mn.sav'.

include "CommonVarsMN.sps".

* Select completed interviews.
select if (MWM17 = 1).

* Weight the data by the men weight.
weight by mnweight.

* Generate numMen variable.
compute numMen = 1.
variable labels numMen "".
value labels numMen 1 "Number of men age 15-49 years".

* Generate indicators.
* Respondents who have ever used a computer are those responding yes to MMT4. Those that used in the last 3 months are those responding 1, 2 or 3 in MMT5 and those using at least once a week are MMT5=2 or 3.
recode MMT4 (1 = 100) (else = 0) into compev.
variable labels compev "Ever".

recode MMT5 (1, 2, 3= 100) (else = 0) into comp3.
variable labels comp3 "During the last 3 months [1]".

recode MMT5 (2, 3 = 100) (else = 0) into comp1w.
variable labels comp1w "At least once a week during the last 3 months".

* Ownership of mobile phone: MMT11=1. Similar to current use of computers, the use of mobile phone in the last 3 months is MMT12=1, 2 or 3 and those using at least weekly are MMT12=2 or 3.
recode MMT11 (1 = 100) (else = 0) into mobile.
variable labels mobile "Own a mobile phone [2]".

recode MMT12 (1, 2, 3= 100) (else = 0) into mobile3.
variable labels mobile3 "During the last 3 months [3]".

recode MMT12 (2, 3 = 100) (else = 0) into mobile1w.
variable labels mobile1w "At least once a week during the last 3 months".

* Ever use of internet is MMT9=1 or MMT6[C]=1 or MMT6[F]=1. Similar to above, the current use is captured through MMT10.
recode MMT9 (1 = 100) (else = 0) into intev.
if (MMT6C = 1 or MMT6F = 1) intev = 100.
variable labels intev "Ever".

recode MMT10 (1, 2, 3 = 100) (else = 0) into int3.
variable labels int3 "During the last 3 months [4]".

recode MMT10 (2, 3 = 100) (else = 0) into int1w.
variable labels int1w "At least once a week during the last three months [5]".

compute layer0 = 0.
variable labels layer0 "".
value labels layer0 0 "Percentage of men age 15-49 who:".

compute layer1 = 0.
variable labels layer1 "".
value labels layer1 0 "Used a computer".

compute layer2 = 0.
variable labels layer2 "".
value labels layer2 0 "Used a mobile phone".

compute layer3 = 0.
variable labels layer3 "".
value labels layer3 0 "Used internet".

compute total = 1.
variable labels total "".
value labels total 1 "Total".

* Labels in French.
* value labels numMen 1 "Nombre d'hommes âgées de 15 à 49 ans".
* variable labels compev "Déjà".
* variable labels comp3 "Durant les 3 derniers mois [1]".
* variable labels comp1w "Au moins une fois par semaine durant les 3 derniers mois".
* variable labels mobile "Posséder un téléphone mobile [2]".
* variable labels mobile3 "Durant les 3 derniers mois [3]".
* variable labels mobile1w "Au moins une fois par semaine durant les 3 derniers mois".
* variable labels intev "Déjà".
* variable labels int3 "Durant les 3 derniers mois [4]".
* variable labels int1w "Au moins une fois par semaine durant les 3 derniers mois [5]".
* value labels layer0 0 "Pourcentage d'hommes de 15-49 ans qui:".
* value labels layer1 0 "Déjà utilisé un ordinateur".
* value labels layer2 0 "Utilisé un téléphone portable".
* value labels layer3 0 "Utilisé Internet".

* Labels in Spanish.
* value labels numMen 1 "Número de hombres de 15-49 años".
* variable labels compev "Alguna vez".
* variable labels comp3 "Durante los últimos 3 meses [1]".
* variable labels comp1w "Al menos una vez a la semana durante los últimos 3 meses".
* variable labels mobile "Posee un teléfono móvil [2]".
* variable labels mobile3 "Usaron un teléfono móvil [3]".
* variable labels mobile1w "Al menos una vez a la semana durante los últimos 3 meses".
* variable labels intev "Alguna vez".
* variable labels int3 "Durante los últimos 3 meses [4]".
* variable labels int1w "Al menos una vez a la semana durante los últimos 3 meses [5]".
* value labels layer0 0 "Porcentaje de hombres de 15-49 años que:".
* value labels layer1 0 "Usaron una computadora".
* value labels layer2 0 "Usaron un teléfono móvil".
* value labels layer3 0 "Usaron internet".

ctables
  /vlabels variables =  numMen layer0 layer1 layer2 layer3 total
         display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
        + $mwage [c]
        + mwelevel [c]
        + mdisability [c]
        + ethnicity [c]
        + windex5 [c]
      by
           layer0 [c] > ( layer1 [c] > (compev [s] [mean '' f5.1]
                        + comp3 [s] [mean '' f5.1]
                        + comp1w [s] [mean '' f5.1])
                        + mobile [s] [mean '' f5.1]
                        + layer2 [c] > (mobile3 [s] [mean '' f5.1]
                        + mobile1w [s] [mean '' f5.1])
                        + layer3 [c] > (intev [s] [mean '' f5.1]
                        + int3 [s] [mean '' f5.1]
                        + int1w [s] [mean '' f5.1] ))
         + numMen[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Table SR.9.3M: Use of ICT (men)"
      "Percentage of men age 15-49 years who have ever used a computer, the internet and who own a mobile phone, " +
      "percentage who have used during the last 3 months and percentage who have used at least once weekly during the last three months, "
     + surveyname
   caption =
        "[1] MICS indicator SR.9 - Use of computer"
        "[2] MICS indicator SR.10 - Ownership of mobile phone; SDG indicator 5.b.1"												
        "[3] MICS indicator SR.11 - Use of mobile phone"									
        "[4] MICS indicator SR.12a - Use of internet (during the last 3 months); SDG indicator 17.8.1"												
        "[5] MICS indicator SR.12b - Use of internet (at least once a week during the last 3 months)".
		
* Ctables in French.
* ctables 
  /vlabels variables =  numMen layer0 layer1 layer2 layer3 total
         display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
        + $mwage [c]
        + mwelevel [c]
        + mdisability [c]
        + ethnicity [c]
        + windex5 [c]
      by
           layer0 [c] > ( layer1 [c] > (compev [s] [mean '' f5.1]
                        + comp3 [s] [mean '' f5.1]
                        + comp1w [s] [mean '' f5.1])
                        + mobile [s] [mean '' f5.1]
                        + layer2 [c] > (mobile3 [s] [mean '' f5.1]
                        + mobile1w [s] [mean '' f5.1])
                        + layer3 [c] > (intev [s] [mean '' f5.1]
                        + int3 [s] [mean '' f5.1]
                        + int1w [s] [mean '' f5.1] ))
         + numMen[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tableau SR.9.3M:  Utilisation d' IOT (hommes)"
     "Pourcentage d'hommes de 15-49 ans qui ont déjà utilisé un ordinateur et Internet, et qui possèdent un téléphone mobile, " +
     "pourcentage qui ont utilisé au cours des 3 derniers mois et pourcentage qui ont utilisé au moins une fois par semaine au cours des 3 derniers mois, "
     + surveyname
   caption =
        "[1] Indicateur MICS SR.9 - Utilisation d’ordinateurs "
        "[2] Indicateur MICS SR.10 - Propriété du téléphone mobile; SDG indicater 5.b.1"												
        "[3] Indicateur MICS SR.11 - L'utilisation du téléphone mobile"									
        "[4] Indicateur MICS SR.12a - Utilisation d'Internet (durant les 3 derniers mois); SDG indicateur 17.8.1"												
        "[5] Indicateur MICS SR.12b - Utilisation d'Internet (au moins une fois par semaine durant les 3 derniers mois)".

* Ctables in Spanish.
* ctables
  /vlabels variables =  numMen layer0 layer1 layer2 layer3 total
         display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
        + $mwage [c]
        + mwelevel [c]
        + mdisability [c]
        + ethnicity [c]
        + windex5 [c]
      by
           layer0 [c] > ( layer1 [c] > (compev [s] [mean '' f5.1]
                        + comp3 [s] [mean '' f5.1]
                        + comp1w [s] [mean '' f5.1])
                        + mobile [s] [mean '' f5.1]
                        + layer2 [c] > (mobile3 [s] [mean '' f5.1]
                        + mobile1w [s] [mean '' f5.1])
                        + layer3 [c] > (intev [s] [mean '' f5.1]
                        + int3 [s] [mean '' f5.1]
                        + int1w [s] [mean '' f5.1] ))
         + numMen[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tabla SR.9.3M: Uso de TIC (hombres)"
     "Porcentaje de hombres de 15-49 años que han usado una computadora e internet y que poseen un teléfono móvil, " +
	 "porcentaje que los han usado durante los últimos 3 meses, y porcentaje que los han usado al menos una vez a la semana durante los últimos 3 meses, "
     + surveyname
   caption =
        "[1] Indicador MICS SR.9 - Uso de computadora"
        "[2] Indicador MICS SR.10 - Propiedad de teléfono móvil; indicador ODS 5.b.1"												
        "[3] Indicador MICS SR.11 - Uso de teléfono móvil"									
        "[4] Indicador MICS SR.12a - Uso de internet (durante los últimos 3 meses; indicador ODS 17.8.1"												
        "[5] Indicador MICS SR.12b - Uso de internet (al menos una vez a la semana durante los últimos 3 meses)".

new file.
