﻿* Encoding: windows-1252.
* MICS5 RH-08.

***.


include "surveyname.sps".

get file = 'wm.sav'.

include "CommonVarsWM.sps".

select if (WM17 = 1).

* select women that gave birth in two years preceeding the survey. 
* IB (5 years in case of SL).
select if (CM17 = 1).

include "surveyname.sps".

weight by wmweight.

* definitions of anc, ageAtBirth .
include 'define\MICS6 - 06 - TM.sps' .

* Define Multiple Response Sets.
mrsets
  /mcgroup name = $antvisits
           label = 'Percentage of women by number of antenatal care visits:'
           variables =  noVisitsAux1 noVisitsAux2 .
		   
* French.
* mrsets
  /mcgroup name = $antvisits
           label = 'Pourcentage de femmes selon le nombre de consultations prénatales:'
           variables =  noVisitsAux1 noVisitsAux2 .
		   
* Spanish.
* mrsets
  /mcgroup name = $antvisits
           label = 'Porcentaje de mujeres según el número de visitas de cuidado prenatal:'
           variables =  noVisitsAux1 noVisitsAux2 .

compute visitTime = 0 .
if (MN4AU >= 8 or MN4AN >= 98) visitTime = 9 .
* 8+ months: weeks 31 and above; months 8 and above.
if ((MN4AU=1 and MN4AN>=31 and MN4AN<98) or (MN4AU=2 and MN4AN>7 and MN4AN<98)) visitTime = 4 .
* 6-7 months: weeks 22-30; months 6,7.
if ((MN4AU=1 and MN4AN<31) or (MN4AU=2 and any(MN4AN,6,7))) visitTime = 3 .
* 4-5 months: weeks 14 - 21; months 4,5.
if ((MN4AU=1 and MN4AN<22) or (MN4AU=2 and any(MN4AN,4,5))) visitTime = 2 .
* First trimestar: weeks 1 - 13, months 1,2,3.
if ((MN4AU=1 and MN4AN<14) or (MN4AU=2 and any(MN4AN,1,2,3))) visitTime = 1 .
variable labels visitTime "Percent distribution of women by number of months pregnant at the time of first antenatal care visit" .
value labels visitTime
  0 "No antenatal care visits"
  1 "Less than 4 months"
  2 "4-5 months"
  3 "6-7 months"
  4 "8+ months"
  9 "DK/Missing"
  .

compute numWomenANC = 0.
if (visitTime >= 1 and visitTime < 9) numWomenANC = 1.
value labels numWomenANC 1 " ".
variable labels numWomenANC "Number of women with a live birth in the last two years who had at least one ANC visit".

do if (visitTime >= 1 and visitTime < 9).
+ compute nmonths = 99.
+ if (MN4AU=1 and MN4AN <98) nmonths = MN4AN*12/52.
+ if (MN4AU=2 and MN4AN <98) nmonths = MN4AN.
+ recode nmonths (99 = sysmis) (else = copy).
end if.

compute numWomen = 1.
value labels numWomen 1 "".
variable labels numWomen "Number of women with a live birth in the last two years".

variable labels nmonths "Median months pregnant at first ANC visit".

compute total = 1.
variable labels total "Total".
value labels total 1" ".

compute total100 = 100.
variable labels total100 "Total".
value labels total100 100" ".

* For labels in French uncomment commands below.
* variable labels
 visitTime "Pourcentage de femmes selon le nombre de consultations prénatales:" 
/numWomenANC "Nombre de femmes ayant eu une naissance vivante dans les 2 dernières années qui ont fait au moins une visite prénatale"
/numWomen "Nombre de femmes ayant eu une naissance vivante dans les 2 dernières années"
/nmonths "Mois médian de grossesse lors de la première visite prénatale".
* value labels visitTime
  0 "Pas de visite prénatale"
  1 "Moins de 4 mois"
  2 "4-5 mois"
  3 "6-7 mois"
  4 "8+ mois"
  9 "NSP/manquant".
  
* For labels in Spanish uncomment commands below.
* variable labels
 visitTime "Distribución porcentual de mujeres por los meses de embarazo en el momento de la primera visita de cuidado prenatal" 
/numWomenANC "Número de mujeres con un nacido vivo en los últimos dos años que tuvieron al menos una visita de cuidado prenatal"
/numWomen "Número de mujeres con un nacido vivo en los últimos dos años"
/nmonths "Mediana de meses de embarazo en la primera visita de cuidado prenatal".
* value labels visitTime
  0 "Ninguna visita de cuidado prenatal"
  1 "Menos de 4 meses"
  2 "4-5 meses"
  3 "6-7 meses"
  4 "8+ meses"
  9 "NS/Ignorado".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /table   total [c]
         + HH6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]        
   by
           $antvisits [c] [rowpct.validn '' f5.1]
         + visitTime [c] [rowpct.validn '' f5.1]
         + total100 [s] [mean '' f5.1] 
         + numWomen [s] [count '' f5.0]
         + nmonths [s] [median '' f5.0]
         + numWomenANC [s] [sum '' f5.0]
  /categories variables=all empty=exclude
  /slabels position=column visible=no
  /titles title=
     "Table TM.4.2: Number of antenatal care visits and timing of first visit"
     "Percentage of women age 15-49 years with a live birth in the last two years by number of antenatal care visits by any provider and by the timing of first antenatal care visits, "     + surveyname 
   caption=
     "[1] MICS indicator TM.5b - Antenatal care coverage (at least four times by any provider); SDG indicator 3.8.1"
     "[2] MICS indicator TM.5c - Antenatal care coverage (at least eight times by any provider)"
  .										
													
* Ctables command in French.
* ctables
  /table   total [c]
         + HH6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]        
   by
           $antvisits [c] [rowpct.validn '' f5.1]
         + visitTime [c] [rowpct.validn '' f5.1]
         + total100 [s] [mean '' f5.1] 
         + numWomen [s] [count '' f5.0]
         + nmonths [s] [median '' f5.0]
         + numWomenANC [s] [sum '' f5.0]
  /categories variables=all empty=exclude
  /slabels position=column visible=no
  /titles title=
     "Tableau TM.4.2: Nombre de consultations prénatales et moment de la première visite"
     "Distribution en pourcentage de femmes de 15-49 ans ayant eu une naissance vivante dans les 2 dernières années selon le nombre de consultations prénatales faites " +
     "par n'importe quel agent de santé et moment de la première visite prénatale, "     + surveyname 
   caption=
     "[1] Indicateur MICS TM.5b - Couverture des soins prénatals (au moins quatre fois par d'un prestataire); Indicateur ODD 3.8.1"
     "[2] Indicateur MICS TM.5c - Couverture des soins prénatals (au moins huit fois par d'un prestataire)"
  .		
  
  * Ctables command in Spanish.
* ctables
  /table   total [c]
         + HH6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]        
   by
           $antvisits [c] [rowpct.validn '' f5.1]
         + visitTime [c] [rowpct.validn '' f5.1]
         + total100 [s] [mean '' f5.1] 
         + numWomen [s] [count '' f5.0]
         + nmonths [s] [median '' f5.0]
         + numWomenANC [s] [sum '' f5.0]
  /categories variables=all empty=exclude
  /slabels position=column visible=no
  /titles title=
     "Tabla TM.4.2: Número de visitas de cuidado prenatal y el momento de la primera visita"
     "Distribución porcentual de mujeres que tuvieron un nacido vivo durante los dos años anteriores a la encuesta por número de visitas de cuidado prenatal " +
     "por cualquier proveedor y el momento de la primera visita, "     + surveyname 
   caption=
     "[1] Indicador MICS TM.5b - Cobertura de atención prenatal (al menos cuatro veces por cualquier proveedor); indicador SDG 3.8.1"
     "[2] Indicador MICS TM.5c - Cobertura de atención prenatal (al menos ocho veces por cualquier proveedor)"
  .		
new file.
