* Encoding: windows-1252.
***.

include "surveyname.sps".

get file = 'wm.sav'.

include "CommonVarsWM.sps".

select if (WM17 = 1).

weight by wmweight.

* select women that gave birth in two years preceeding the survey.
select if (CM17 = 1).

* definitions of anc, ageAtBirth .
include 'define\MICS6 - 06 - TM.sps' .

variable labels skilledAttendant "Delivery assisted by any skilled attendant [1]".

recode MN22 (1=100) (else=0) into cBefore .
recode MN22 (2=100) (else=0) into cAfter .
recode MN22 (1,2=100) (else=0) into cTotal .
variable labels 
   cBefore "Decided before onset of labour pains"
  /cAfter "Decided after onset of labour pains"
  /cTotal "Total [2]" .

compute cLayer = 0.
value labels cLayer 0 "Percent delivered by C-section" .

compute numWomen = 1.
variable labels numWomen "Number of women who had a live birth in the last two years".
value labels numWomen 1 "".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

compute total100 = 100.
variable labels total100 "Total".
value labels total100 100 " ".

value labels noVisitsAux1
  0 "None"
  0.1 "1-3 visits"
  1 "4+ visits"
  2 "   8+ visits"
  9 "DK/Missing".

compute DeliveryDoctor       = 100 * (personAtDelivery = 11).
compute DeliveryNurse        = 100 * (personAtDelivery = 12).
compute DeliveryOtherqual = 100 * (personAtDelivery = 13).
compute DeliveryTraditional    = 100 * (personAtDelivery = 14).
compute DeliveryCommunity      = 100 * (personAtDelivery = 15).
compute DeliveryRelative  = 100 * (personAtDelivery = 16).
compute DeliveryOther        = 100 * (personAtDelivery = 97).
compute DeliveryNone         = 100 * (personAtDelivery = 98).

variable labels DeliveryDoctor       "Medical doctor".
variable labels DeliveryNurse        "Nurse / Midwife".
variable labels DeliveryOtherqual "Other qualified".
variable labels DeliveryTraditional  "Traditional birth attendant".
variable labels DeliveryCommunity    "Community / village health worker".
variable labels DeliveryRelative     "Relative / Friend".
variable labels DeliveryOther        "Other/Missing".
variable labels DeliveryNone         "No attendant".

compute layer1 = 0.
value labels layer1 0 "Person assisting the delivery".

compute layer11 = 0.
value labels layer11 0 "Skilled attendant".

compute layer12 = 0.
value labels layer12 0 "Other".

* Define Multiple Response Sets.
mrsets
  /mcgroup name = $antvisits
           label = 'Number of antenatal care visits'
           variables =  noVisitsAux1 noVisitsAux2 .
		   
* For labels in French uncomment commands below.
* variable labels DeliveryDoctor       "Mdecin".
* variable labels DeliveryNurse        "Infirmire / sage-Femme".
* variable labels DeliveryOtherqual "Autre medical".
* variable labels DeliveryTraditional  "Accoucheuse traditionnelle".
* variable labels DeliveryCommunity    "Agent de sant communautaire".
* variable labels DeliveryRelative     "Parent/Ami".
* variable labels DeliveryOther        "Autre/manquant".
* variable labels DeliveryNone         "Aucune assistance".
* value labels layer1 0 "Personne assistant l'accouchement".
* value labels layer12 0 "Autre".
* value labels layer11 0 "Personnel qualifi".
* mrsets
  /mcgroup name = $antvisits
           label = 'Nombre de visites prnatales'
           variables =  noVisitsAux1 noVisitsAux2 .
* variable labels
   numWomen "Nombre de femmes ayant eu une naissance vivante dans les 2 dernires annes"
   /skilledAttendant "Accouchement avec une assistance qualifie [1]"
   /cBefore "Dcid avant le dbut des douleurs de l'accouchement"
  /cAfter "Decided after onset of labour pains"
  /cTotal "Total [2]".
* value labels 
noVisitsAux1
  0 "Aucune"
  0.*1 "1-3 visites"
  1 "4+ visites"
  2 "   8+ visites"
  9 "NSP/Manquant"
/cLayer 0 "Pourcentage accouch par csarienne" .

		   
* For labels in Spanish uncomment commands below.
* variable labels DeliveryDoctor       "Medical doctor".
* variable labels DeliveryNurse        "Nurse / Midwife".
* variable labels DeliveryOtherqual "Other qualified".
* variable labels DeliveryTraditional  "Traditional birth attendant".
* variable labels DeliveryCommunity    "Community / village health worker".
* variable labels DeliveryRelative     "Relative / Friend".
* variable labels DeliveryOther        "Other/Missing".
* variable labels DeliveryNone         "No attendant".
* value labels layer1 0 "Person assisting the delivery".
* value labels layer11 0 "Skilled attendant".
* value labels layer12 0 "Other".
* mrsets
  /mcgroup name = $antvisits
           label = 'Nmero de visitas de cuidado prenatal'
           variables =  noVisitsAux1 noVisitsAux2 .
* variable labels
   numWomen "Nmero de mujeres con un nacido vivo en los 2 ltimos aos"
   /skilledAttendant "Asistencia en el parto por una persona capacitada [1]"
   /cBefore "Decidida antes de la aparicin de los dolores de parto"
  /cAfter "Decidida despus de la aparicin de los dolores de parto"
  /cTotal "Total [2]".
* value labels 
noVisitsAux1
  0 "Ninguna"
  0.*1 "1-3 visitas"
  1 "4+ visitas"
  2 "   8+ visitas"
  9 "NS/Ignorado"
/cLayer 0 "Porcentaje nacimientos por cesrea" .

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = cLayer layer1 layer11 layer12 display = none
  /table   total [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]         
         + ageAtBirth [c]
         + $antvisits [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]     
   by
           layer1 [c] > 
             (layer11 [c] > (DeliveryDoctor [s][mean F3.1]
                          + DeliveryNurse [s][mean F3.1]
                          + DeliveryOtherqual [s][mean F3.1])
            + layer12 [c] > (DeliveryTraditional [s][mean F3.1]
                          + DeliveryCommunity [s][mean F3.1]
                          + DeliveryRelative [s][mean F3.1]
                          + DeliveryOther [s][mean F3.1])
            + DeliveryNone [s][mean F3.1])
         + total100 [s] [mean '' f5.1]
         + skilledAttendant [s] [mean '' f5.1] 
         + cLayer [c] > (cBefore [s] [mean '' f5.1]  + cAfter [s] [mean '' f5.1]  + cTotal [s] [mean '' f5.1] )
         + numWomen [s] [count '' f5.0]
  /categories variables=all empty=exclude
  /slabels position=column visible=no
  /titles title=
      "Table TM.6.2: Assistance during delivery and caesarian section"
      "Percent distribution of women age 15-49 years with a live birth in the last two years by person providing assistance at delivery, and percentage of births delivered by C-section, " + surveyname
   caption=
      "[1] MICS indicator TM.9 - Skilled attendant at delivery; SDG indicator 3.1.2"														
      "[2] MICS indicator TM.10 - Caesarean section"
  .
  
* Ctables command in French.
* ctables
  /vlabels variables = cLayer layer1 layer11 layer12 display = none
  /table   total [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]         
         + ageAtBirth [c]
         + $antvisits [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]     
   by
           layer1 [c] > 
             (layer11 [c] > (DeliveryDoctor [s][mean F3.1]
                          + DeliveryNurse [s][mean F3.1]
                          + DeliveryOtherqual [s][mean F3.1])
            + layer12 [c] > (DeliveryTraditional [s][mean F3.1]
                          + DeliveryCommunity [s][mean F3.1]
                          + DeliveryRelative [s][mean F3.1]
                          + DeliveryOther [s][mean F3.1])
            + DeliveryNone [s][mean F3.1])
         + total100 [s] [mean '' f5.1]
         + skilledAttendant [s] [mean '' f5.1] 
         + cLayer [c] > (cBefore [s] [mean '' f5.1]  + cAfter [s] [mean '' f5.1]  + cTotal [s] [mean '' f5.1] )
         + numWomen [s] [count '' f5.0]
  /categories variables=all empty=exclude
  /slabels position=column visible=no
  /titles title=
      "Tableau TM.6.2: Assistance  l'accouchement et accouchement par csarienne"
      "Distribution en pourcentage des femmes de 15-49 ans ayant eu une naissance vivante dans les 2 dernires annes selon la personne qui a assist l'accouchement et pourcentage de naissances accouches par csarienne, " + surveyname
   caption=
      "[1] Indicateur MICS TM.9 - Assistance qualifie  l'accouchement ; Indicateur ODD 3.1.2"														
      "[2] Indicateur MICS TM.10 - Accouchement par csarienne"
  .
 
* Ctables command in Spanish.
* ctables
  /vlabels variables = cLayer layer1 layer11 layer12 display = none
  /table   total [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]         
         + ageAtBirth [c]
         + $antvisits [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]     
   by
           layer1 [c] > 
             (layer11 [c] > (DeliveryDoctor [s][mean F3.1]
                          + DeliveryNurse [s][mean F3.1]
                          + DeliveryOtherqual [s][mean F3.1])
            + layer12 [c] > (DeliveryTraditional [s][mean F3.1]
                          + DeliveryCommunity [s][mean F3.1]
                          + DeliveryRelative [s][mean F3.1]
                          + DeliveryOther [s][mean F3.1])
            + DeliveryNone [s][mean F3.1])
         + total100 [s] [mean '' f5.1]
         + skilledAttendant [s] [mean '' f5.1] 
         + cLayer [c] > (cBefore [s] [mean '' f5.1]  + cAfter [s] [mean '' f5.1]  + cTotal [s] [mean '' f5.1] )
         + numWomen [s] [count '' f5.0]
  /categories variables=all empty=exclude
  /slabels position=column visible=no
  /titles title=
      "Tabla TM.6.2: Asistencia durante el parto y cesrea"
      "Distribucin porcentual de mujeres de 15-49 aos que tuvieron un nacido vivo en los ltimos dos aos por persona que asiste en el parto y porcentaje de nacimientos por cesrea, " + surveyname
   caption=
      "[1]  Indicador MICS TM.9 - Asistencia en el parto por una persona capacitada; indicador ODS  3.1.2"														
      "[2]  Indicador MICS TM.10 - Cesrea"
  .
								
new file.

