﻿* Encoding: windows-1252.
***.
include "surveyname.sps".

get file = 'wm.sav'.

include "CommonVarsWM.sps".

select if (WM17 = 1).

weight by wmweight.

*select women that gave birth in two years preceeding the survey.
select if (CM17 = 1).

* definitions of anc, ageAtBirth .
include 'define\MICS6 - 06 - TM.sps' .

select if (deliveryPlace<>11 and deliveryPlace<>12).

variable labels MN28 "Instrument used to cut the cord".

compute layer = 0.
variable labels layer "".
value labels layer 0 "Percentage of children whose cord was cut with:".

* The percentage of children whose cord was cut with a boiled or sterilised instrument are those responding 'yes' to MN29, 
while the percentage cut with a clean instrument are those cut with a new blade (or a used blade or scissors that was boiled or sterilised before use (MN28=1 or (MN28= 2 or 3 AND MN29=1)).
compute sterilInst = 0.
if (MN29 = 1) sterilInst = 100.
variable labels sterilInst "Boiled or sterilised instruments".

compute cleanInst = 0.
if (MN28=1 or ((MN28= 2 or MN28= 3) AND MN29=1)) cleanInst = 100.
variable labels cleanInst "A clean instrument [1] [A]".

* Nothing: MN30=2.
* Chlorhexidine or other antiseptic: MN31=A and/or B.
* Other non-harmful substance: Should be deleted in surveys where no non-harmful substance is included. The MICS standard questionnaire does not include such.
* Harmful substances: MN31=C, D and/or E.
* Percentage with nothing harmful applied to the cord: MN30=2 or MN31<>C, D, E, X or Z.

compute nothing = 0.
if (MN30 = 2) nothing = 100.
variable labels nothing "Nothing".

compute antiseptic = 0.
if (MN31A ="A" or MN31B = "B") antiseptic = 100.
variable labels antiseptic "Chlorhexidine or other antiseptic".

compute Harm = 0.
if (MN31C = "C" or MN31D = "D" or MN31E = "E" or MN31X = "X") Harm = 100.
variable labels Harm "Harmful substance".

compute nonHarm = 0.
if (nothing = 100 or antiseptic = 100) nonHarm = 100.
variable labels nonHarm "Percentage with nothing harmful applied to the cord [2]".

compute layer1 = 0.
variable labels layer1 "".
value labels layer1 0 "Substances [B] applied to the cord".

compute numChildren = 1.
variable labels numChildren "Number of last-born children in the last 2 years delivered outside a facility".
value labels  numChildren 1 "".

compute total = 1.
variable labels total "Total".
value labels  total 1 " ".

variable labels welevel "Mother’s education".
variable labels ageAtBirth "Mother’s age at delivery".
variable labels disability "Mother's functional disabilities (age 18-49 years)".

* For labels in French uncomment commands below.
* variable labels
      MN28 "Instrument utilisé pour couper le cordon"
	 /sterilInst "Instruments bouillis ou stérilisés"
	 /cleanInst "Un instrument propre [1] [A]"
	 /nothing "Rien"
	 /antiseptic "Chlorhexidine ou autre antiseptique"
	 /Harm "Substance nocive"
	 /nonHarm "Pourcentage sans rien de nuisible appliqué au cordon [2]"	 
	 /numChildren "Nombre d'enfants nés au cours des deux dernières années à l'extérieur d'un établissement"
	 /welevel "Mother’s education"
	 /ageAtBirth "Mother’s age at delivery"
	 /disability "Mother's functional disabilities (age 18-49 years)".
* value labels 
      layer 0 "Pourcentage d'enfants dont le cordon a été coupé avec:"
	 /layer1 0 "Substances [B] appliquées sur le cordon".
	 
* For labels in Spanish uncomment commands below.
* variable labels
      MN28 "Instrumento empleado para cortar el cordón"
	 /sterilInst "Instrumentos hervidos o esterelizados"
	 /cleanInst "Un instrumento limpio [1] [A]"
	 /nothing "Nada"
	 /antiseptic "Chlorhexidine u otros antisepticos"
	 /Harm "Sustancias dañinas"
	 /nonHarm "Porcentaje a los que no se les aplicó nada dañino al cordón [2]"	 
	 /numChildren "Número de últimos nacidos vivos en los últimos 2 años tenidos fuera de una instalación"
	 /welevel "Mother’s education"
	 /ageAtBirth "Mother’s age at delivery"
	 /disability "Mother's functional disabilities (age 18-49 years)".
* value labels 
      layer 0 "Porcentaje de niños cuyo cordón fue cortado con:"
	 /layer1 0 "Sustancias [B] aplicada al cordón".
	 
	 
* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = layer layer1 display = none
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + personAtDelivery1 [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
     by
          MN28[c] [rowpct.validn '' f5.1] +   
          layer [c] > 
          (sterilInst [s] [mean '' f5.1] + cleanInst [s] [mean '' f5.1]) + 
          layer1 [c] > 
          (nothing [s] [mean '' f5.1] + antiseptic [s] [mean '' f5.1] + Harm [s] [mean '' f5.1]) + 
         nonHarm [s] [mean '' f5.1] + 
         numChildren[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /categories variables=MN28 total=yes position = after label = "Total"
  /slabels position=column visible=no
  /titles title="Table TM.8.5: Cord cutting and care"
	"Percent distribution of last live births in the last 2 years delivered outside a facility by what instrument was used to cut the umbilical cord and what substance was applied to the cord,  " +
                   surveyname
   caption=
      "[1] MICS indicator TM.17 - Cord cut with clean instrument"  															
      "[2] MICS indicator TM.18 - Nothing harmful applied to cord"														
      "[A] Clean instruments are all new blades and boiled or sterilised used blades or scissors"														
      "[B] Substances include: Chlorhexidine, other antiseptic (such as alcohol, spirit, gentian violet), mustard oil, ash, animal dung and others. Mustard oil, ash and animal dung are considered harmful".													

* Ctables command in French.
* ctables
  /vlabels variables = layer layer1 display = none
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + personAtDelivery1 [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
     by
          MN28[c] [rowpct.validn '' f5.1] +   
          layer [c] > 
          (sterilInst [s] [mean '' f5.1] + cleanInst [s] [mean '' f5.1]) + 
          layer1 [c] > 
          (nothing [s] [mean '' f5.1] + antiseptic [s] [mean '' f5.1] + Harm [s] [mean '' f5.1]) + 
         nonHarm [s] [mean '' f5.1] + 
         numChildren[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /categories variables=MN28 total=yes position = after labels = "Total"
  /slabels position=column visible=no
  /titles title="Tableau TM.8.5: Coupe et entretien du cordon"
	"Pourcentage de la distribution des dernières naissances vivantes au cours des deux dernières années à l'extérieur d'un établissement, en fonction de l'instrument utilisé pour couper le cordon ombilical et de la substance appliquée au cordon,  " +
                   surveyname
   caption=
      "[1] Indicateur MICS TM.17 - Cordon coupé avec un instrument propre "  															
      "[2] Indicateur MICS TM.18 - Rien de nuisible appliqué sur le cordon"														
      "[A] Les instruments propres sont tous de nouvelles lames et des lames ou des ciseaux bouillis ou stérilisés."														
      "[B] Les substances comprennent: la chlorhexidine, d'autres antiseptiques (comme l'alcool, l'alcool, le violet de gentiane), l'huile de moutarde, la cendre, " +
      "la bouse d'animaux et autres. L'huile de moutarde, la cendre et la bouse d'animaux sont considérées nocives".													


* Ctables command in Spanish.
* ctables
  /vlabels variables = layer layer1 display = none
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + personAtDelivery1 [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
     by
          MN28[c] [rowpct.validn '' f5.1] +   
          layer [c] > 
          (sterilInst [s] [mean '' f5.1] + cleanInst [s] [mean '' f5.1]) + 
          layer1 [c] > 
          (nothing [s] [mean '' f5.1] + antiseptic [s] [mean '' f5.1] + Harm [s] [mean '' f5.1]) + 
         nonHarm [s] [mean '' f5.1] + 
         numChildren[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /categories variables=MN28 total=yes position = after labels = "Total"
  /slabels position=column visible=no
  /titles title="Tabla TM.8.5: Corte y cuidado del cordón umbilical"
	"Distribución porcentual  de los últimos nacidos vivos en los últimos 2 años tenidos fuera de una instalación según qué instrumento se usó para cortar el cordón y qué sustancia se aplicó al cordón,  " +
                   surveyname
   caption=
      "[1] Indicador MICS TM.17 - Corte del cordón con un instrumento limpio "  															
      "[2] Indicador MICS TM.18 - Nada dañino aplicado al cordón"														
      "[A] Los instrumentos limpios comprenden cuchillas nuevas y las ya usadas o tijeras que has sido hervidas o esterelizadas"														
      "[B] ustancias incluidas: Chlorhexidine, otros antisepticos (como alcohol, bebidas alcohólicas, violeta genciana), aceite de mostaza, cenizas, " +
      "excrementos de animales y otros. El aceite de mostaza, las cenizas, y los excrementos de animales se consideran dañinos".													

	  
new file.
