﻿* Encoding: windows-1252.
*2018.08.22: The calculation of weight assesment is corrected from:
 if (PN30 = 1) WeightAssessment = 100. 
*to
*if (PN29 = 1) WeightAssessment = 100.
***.
include "surveyname.sps".

get file = 'wm.sav'.

include "CommonVarsWM.sps".

select if (WM17 = 1).

weight by wmweight.

*select women that gave birth in two years preceeding the survey.
select if (CM17 = 1).

* definitions of anc, ageAtBirth .
include 'define\MICS6 - 06 - TM.sps' .

compute layer = 0.
variable labels layer "".
value labels layer 0 "Percentage of newborn receiving postnatal signal care function of:".

* Those receiving postnatal care functions are:
* Cord examination: PN25[A]=1.
* Temperature assessment: PN25[B]=1.
* Counseling on breastfeeding: PN25[C]=1.
* Observation of breastfeeding: PN27=1.
* Weight assessment: PN29=1.
* Information on the symptoms requiring care-seeking: PN30=1.

compute cordExam = 0.
if (PN25A = 1) cordExam = 100.
variable labels cordExam "Cord examination".

compute TempAssessment = 0.
if (PN25B = 1) TempAssessment = 100.
variable labels TempAssessment "Temperature assessment".

compute BreasfeedingC = 0.
if (PN25C = 1) BreasfeedingC = 100.
variable labels BreasfeedingC "Counseling".

compute BreasfeedingO = 0.
if (PN27 = 1) BreasfeedingO = 100.
variable labels BreasfeedingO "Observation".

compute BreasfeedingBoth = 0.
if (PN25B = 1 or PN27 = 1) BreasfeedingBoth = 100.
variable labels BreasfeedingBoth "Counseling or observation".

compute WeightAssessment = 0.
if (PN29 = 1) WeightAssessment = 100.
variable labels WeightAssessment "Weight assessment".

compute CareSeek = 0.
if (PN30 = 1) CareSeek = 100.
variable labels CareSeek "Receiving information on the symptoms requiring care-seeking".

* Percentage of newborns who received a least 2 of the preceding signal postnatal care functions within 2 days after birth.
compute pncCheck = cordExam +  TempAssessment + BreasfeedingC + BreasfeedingO + BreasfeedingBoth + WeightAssessment + CareSeek.
recode pncCheck (200 thru hi = 100) (else = 0).
variable labels pncCheck " Percentage of newborns who received a least 2 of the preceding postnatal signal care functions within 2 days after birth [1]".

variable labels disability "Functional difficulties (age 18-49 years)".

compute numChildren = 1.
variable labels numChildren "Number of lastborn children in the last two years".
value labels  numChildren 1 "".

compute total = 1.
variable labels total "Total".
value labels  total 1 " ".

compute layer1 = 0.
variable labels layer1 "".											  
value labels layer1 0 "Breastfeeding".

variable labels welevel "Mother’s education".
variable labels ageAtBirth "Mother’s age at delivery".
variable labels disability "Mother's functional disabilities (age 18-49 years)".


* For labels in French uncomment commands below.
* variable labels 
    cordExam "Examen du cordon"
   /TempAssessment "Évaluation de la température"
   /BreasfeedingC "Conseils"
   /BreasfeedingO "Observation"
   /BreasfeedingBoth "Conseil ou observation"
   /WeightAssessment "Évaluation du poids"
   /CareSeek "Recevoir des informations sur les symptômes nécessitant une prise en charge"
   /pncCheck " Pourcentage de nouveau-nés qui ont reçu au moins deux des fonctions de soins postnatales signalées dans les deux jours suivant la naissance [1]"
   /numChildren "Nombre d'enfants nés au cours des deux dernières années"
   /welevel "Mother’s education"
   /ageAtBirth "Mother’s age at delivery"
   /disability "Mother's functional disabilities (age 18-49 years)".
* value labels layer 0 "Pourcentage de nouveau-nés recevant le signal de soins postnatals fonctions de:"
   /layer1 0 "Breastfeeding".


* For labels in Spanish uncomment commands below.
* variable labels 
    cordExam "Examen del cordón"
   /TempAssessment "Evaluación  de la temperatura"
   /BreasfeedingC "Lactancia: Consejería"
   /BreasfeedingO "Lactancia: Observación"
   /BreasfeedingBoth "Lactancia: Consejería u observación"
   /WeightAssessment "Evaluación del peso"
   /CareSeek "Recibieron información sobre los síntomas que requieren atención"
   /pncCheck "Porcentaje de recien nacidos que recibieron al menos 2 de las funciones fundamentales de la atención postnatal dentro de los  2 días después del nacimiento [1]"
   /numChildren "Número de últimos nacidos vivos en los últimos 2 años "
   /welevel "Mother’s education"
   /ageAtBirth "Mother’s age at delivery"
   /disability "Mother's functional disabilities (age 18-49 years)".
* value labels layer 0 "Porcentaje de recien nacidos que fueron sometidos (o sus madres) a:"
   /layer1 0 "Breastfeeding".


* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = layer layer1 display = none
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
     by
           layer [c] > 
          (cordExam [s] [mean '' f5.1] + TempAssessment [s] [mean '' f5.1] + layer1 [c] > (BreasfeedingC [s] [mean '' f5.1] + BreasfeedingO [s] [mean '' f5.1] + BreasfeedingBoth [s] [mean '' f5.1]) + 
              WeightAssessment [s] [mean '' f5.1] + CareSeek [s] [mean '' f5.1]) +
         pncCheck [s] [mean '' f5.1] + 
         numChildren[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /slabels position=column visible=no
  /titles title="Table TM.8.6: Content of postnatal care for newborns"
	"Percentage of last live births in the last 2 years for which within 2 days after birth the umbilical cord was examined, "+
                   "the temperature of the newborn was assessed, breastfeeding counseling was done or breastfeeding observed, " +
                   "the newborn was weighed and counseling on danger signs for newborns was done, " + surveyname
   caption=
      "[1] MICS indicator TM.19 - Postnatal signal care functions".

* Ctables command in French.
* ctables
  /vlabels variables = layer display = none
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
     by
           layer [c] > 
          (cordExam [s] [mean '' f5.1] + TempAsses [s] [mean '' f5.1] + layer1 [c] > (BreasfeedingC [s] [mean '' f5.1] + BreasfeedingO [s] [mean '' f5.1] + BreasfeedingBoth [s] [mean '' f5.1]) + 
              WeightAsses [s] [mean '' f5.1] + CareSeek [s] [mean '' f5.1]) +
         pncCheck [s] [mean '' f5.1] + 
         numChildren[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /slabels position=column visible=no
  /titles title="Tableau TM.8.6: Contenu des soins postnatals pour les nouveau-nés"
	"Pourcentage des dernières naissances vivantes des deux dernières années pour lesquelles le cordon ombilical a été examiné dans les 2 jours après la naissance, "+
	"évaluation de la température du nouveau-né, conseil d'allaitement maternel ou allaitement observé, pesée du nouveau-né et conseil sur les signes de danger pour les nouveau-nés a été fait, " + surveyname
   caption=
      "[1] Indicateur MICS TM.19 - Fonctions de signal de soins postnataux".


* Ctables command in Spanish.
* ctables
  /vlabels variables = layer display = none
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
     by
           layer [c] > 
          (cordExam [s] [mean '' f5.1] + TempAsses [s] [mean '' f5.1] + layer1 [c] > (BreasfeedingC [s] [mean '' f5.1] + BreasfeedingO [s] [mean '' f5.1] + BreasfeedingBoth [s] [mean '' f5.1]) + 
              WeightAsses [s] [mean '' f5.1] + CareSeek [s] [mean '' f5.1]) +
         pncCheck [s] [mean '' f5.1] + 
         numChildren[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /slabels position=column visible=no
  /titles title="Tabla TM.8.6: Contenido del cuidado post-natal para el recién nacido "
	"Porcentaje de los últimos nacidos vivos en los los últimos dos años para los cuales durante los 2 días después del nacimiento se les examinó el cordón umbilical, se les tomó la temperatura, "+
	"se les dió consejos a la madre sobre la lactancia y se observó durante la lactancia, se pesó al recien nacido y se enseñaron los signos que requieren atención en el recien nacido, " + surveyname
   caption=
      "[1] Indicador MICS TM.19 - Funciones fundamentales de la atención postnatal ".

new file.
