﻿* Encoding: windows-1252.
***.
include "surveyname.sps".

get file = 'wm.sav'.

include "CommonVarsWM.sps".

select if (WM17 = 1).

weight by wmweight.

*select women that gave birth in two years preceeding the survey.
select if (CM17 = 1).

* definitions of anc, ageAtBirth .
include 'define\MICS6 - 06 - TM.sps' .

* Health check following birth while in facility or while at home.
compute healthCheck = 0.
if (PN5 = 1 or PN9 = 1) healthCheck = 100.
variable labels healthCheck "Health check following birth while in facility or at home [A]".

compute pncCheck = 0.
if (healthCheck = 100 or (pncVisitM =1 or pncVisitM = 2 or pncVisitM = 3)) pncCheck = 100.
variable labels pncCheck "Post-natal health check for the mother [1] [C]".

compute numWomen = 1.
variable labels numWomen "Number of women with a live birth in the last 2 years".
value labels  numWomen 1 "".

compute total = 1.
variable labels total "Total".
value labels  total 1 " ".

variable labels pncVisitM "PNC visit for mothers [B]".

* For labels in French uncomment commands below.
* variable labels 
    healthCheck "Examens de santé après la naissance tout en étant dans un centre de santé ou à domicile [A]"
   /pncCheck "Examen de santé post-natal pour la mère [1] [C]"
   /numWomen "Nombre de femmes ayant eu une naissance vivante dans les 2 dernières années"
   /pncVisitM "Visite de la PNC pour les mères [B]".


* For labels in Spanish uncomment commands below.
* variable labels 
    healthCheck "Revisión de salud inmediatamente después del nacimiento en el centro de salud o en la casa [A]"
   /pncCheck "Revisión de salud post-natal para la madre [1] [C]"
   /numWomen "Número de mujeres con un nacido vivo en lo últimos dos años"
   /pncVisitM "Visita CPN para madres [B]".
   
   
* Ctables command in English (currently active, comment it out if using different language).
ctables
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + deliveryType [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
     by
           healthCheck [s] [mean '' f5.1]
         + pncVisitM [c] [rowpct.validn '' f5.1]
         + pncCheck [s] [mean '' f5.1]
         + numWomen[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /categories variables=pncVisitM empty=exclude total=yes
  /slabels position=column visible=no
  /titles title="Table TM.8.7: Post-natal health checks for mothers"
	"Percentage of women age 15-49 years with a live birth in the last two years who received health checks " +
                "while in facility or at home following birth, percent distribution who received post-natal care (PNC) visits from any " + 
                "health provider after birth at the time of last birth, by timing of visit, and percentage who received post natal health checks, " + surveyname
   caption=
 "[1] MICS indicator TM.20 - Post-natal health check for the mother"
 "[A] Health checks by any health provider following facility births (before discharge from facility) or following home births (before departure of provider from home)."									
 "[B] Post-natal care visits (PNC) refer to a separate visit by any health provider to check on the health of the mother and provide preventive care services. "
  "PNC visits do not include health checks following birth while in facility or at home (see note A above)."							
 "[C] Post-natal health checks include any health check performed while in the health facility or at home following birth (see note A above), as well as PNC visits (see note B above) within two days of delivery.".	
							
							
* Ctables command in French.
* ctables
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + deliveryType [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
     by
           healthCheck [s] [mean '' f5.1]
         + pncVisitM [c] [rowpct.validn '' f5.1]
         + pncCheck [s] [mean '' f5.1]
         + numWomen[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /categories variables=pncVisitM empty=exclude total=yes
  /slabels position=column visible=no
  /titles title="Tableau TM.8.7: Examens de santé post-natals des mères"
	"Pourcentage de femmes de 15-49 ans ayant eu une naissance vivante dans les 2 dernières années qui ont bénéficié d'examens de santé pendant qu'elles étaient dans la structure de santé ou à la maison après la naissance, " +
	"distribution en pourcentage de celles qui ont reçu des visites d'examens de santé post-natals de n'importe quel agent de santé " +
                  "après la naissance au moment de la dernière naissance, selon le calendrier des visites et pourcentage qui ont reçu des examens de santé post-natals, " + surveyname
   caption=
 "[1] Indicateur MICS TM.20 - Examen de santé post-natal de la mère"
 "[A] Des bilans de santé effectués par tout prestataire de soins après les accouchements (avant la sortie de l'établissement) ou après les accouchements à domicile (avant le départ du prestataire de la maison)."									
 "[B] Les visites post-natales (PNC) se réfèrent à une visite séparée par un prestataire de santé pour vérifier la santé de la mère et fournir des services de soins préventifs. " +
 "Les visites de la PNC n'incluent pas les bilans de santé après la naissance dans l'établissement ou à la maison (voir note a ci-dessus)."							
 "[C] Les bilans de santé postnatals comprennent les bilans de santé effectués dans l'établissement de santé ou à la maison après la naissance (voir note a ci-dessus), " +
 "ainsi que les visites PNC (voir note b ci-dessus) dans les deux jours suivant l'accouchement.".	
						
							
* Ctables command in Spanish.
* ctables
  /table   total [c]
         + bh3_last [c]
         + hh6 [c]
         + hh7 [c]
         + welevel [c]
         + ageAtBirth [c]
         + $deliveryPlace [c]
         + deliveryType [c]
         + disability [c]
         + ethnicity[c]
         + windex5 [c]   
     by
           healthCheck [s] [mean '' f5.1]
         + pncVisitM [c] [rowpct.validn '' f5.1]
         + pncCheck [s] [mean '' f5.1]
         + numWomen[s] [count '' f5.0]
  /categories variables=all empty=exclude
  /categories variables=pncVisitM empty=exclude total=yes
  /slabels position=column visible=no
  /titles title="Tabla TM.8.7: Revisiones post-natales para las madres"
	"Porcentaje de mujeres de 15-49 años con un nacido vivo en los últimos dos años que recibieron revisiones de salud en el centro de salud o en la casa inmediatamente después del nacimiento, "+
	"distribución porcentual que recibieron visitas de cuidado post-natal (CPN) de un proveedor de salud después del nacimiento del último nacimiento, por momento de la visita, y porcentaje que recibió revisiones de salud post natal, " + surveyname
   caption=
 "[1] Indicador MICS TM.20 - Chequeos post-natales para la madre"
 "[A] Controles de salud realizados por cualquier proveedor de servicios de salud después de nacimientos en el centro de atención (antes del alta de la instalación) " +
 "o después de partos en el hogar (antes de la salida del proveedor de la casa)."									
 "[B] Las visitas de atención postnatal (CPN) se refieren a una visita separada de cualquier proveedor de salud para controlar la salud de la madre y brindar servicios de atención preventiva. " +
 "Las visitas a la PNC no incluyen controles de salud posteriores al nacimiento mientras se encuentran en el centro o en el hogar (consulte la nota A)."							
 "[C] Los controles de salud postnatales incluyen cualquier revisión de salud realizada en el centro de salud o en el hogar después del nacimiento (ver nota A), " +
 "así como las visitas a la CPN (ver nota B arriba) dentro de los dos días posteriores al parto.".	
												
new file.
