* Encoding: UTF-8.
* MICS6 TC-10.1.

 * Indicator 6.2 is calculated as: Engagement of household members age 15 or over in four or more activities (EC5 [A] to [F] = A, B or X).

 * Indicator 6.2, the mean number of activities in which household members engage with the child, and indicators 6.3 and 6.4 are calculated
   irrespective of the number of household members and whether mother or father are living in the household.

 * These denominators are established using data from the List of Household Members: HL12 and HL13, for mothers, and HL16 and HL17, for fathers.

 * The maximum number of activities with whom adult household members have engaged is 6, as asked in the under-5 questionnaire. The activities 
   include (EC5): (A) Reading books to or looking at picture books with the child, (B) Telling stories to the child, (C) Singing songs to or with the child, 
   including lullabies, (D) Taking the child outside the home, compound, yard, or enclosure, (E) Playing with the child, and (F) Naming, counting, or drawing things to or with the child. 

***.


* Call include file for the working directory and the survey name.
include "surveyname.sps".

* open hl file to get info regarding mother (hl14) and father (hl18) being in household.
get file = 'hl.sav'.

* sorting the data.
sort cases by hh1 hh2 hl1.

* creating tmp file.
save outfile = 'tmp.sav'
     /keep = hh1 hh2 hl1 hl14 hl18 felevel
     /rename = (hl1 = ln) .

* Open household members data file.
get file = 'ch.sav'.

sort cases by hh1 hh2 ln.

* merging the data .
match files
  /file = *
  /table = 'tmp.sav'
  /by hh1 hh2 ln.

* recode variables in order to calculate percentages.
recode hl14 (sysmis, 0 = 0) (else = 100).
recode hl18 (sysmis, 0 = 0) (else = 100).

variable labels hl14 'Mother' .
variable labels hl18 'Father' .

* Select completed under 5 questionnaires.
select if (UF17  = 1 and UB2>=2).
weight by chweight.

* calculation of the indicators.
* 1 MICS indicator TC.49a - Support for learning.
compute ind62sum = 
	((EC5AA='A') or (EC5AB='B') or (EC5AX='X')) +
	((EC5BA='A') or (EC5BB='B') or (EC5BX='X')) +
	((EC5CA='A') or (EC5CB='B') or (EC5CX='X')) +
	((EC5DA='A') or (EC5DB='B') or (EC5DX='X')) +
	((EC5EA='A') or (EC5EB='B') or (EC5EX='X')) +
	((EC5FA='A') or (EC5FB='B') or (EC5FX='X')) .

compute ind62 = (ind62sum >= 4) * 100 .

* 2 MICS Indicator TC.49b - Father's support for learning.
compute ind63sum = (EC5AB='B') +
                   (EC5BB='B') +
                   (EC5CB='B') +
                   (EC5DB='B') +
                   (EC5EB='B') +
                   (EC5FB='B') .

compute ind63 = (ind63sum >= 4) * 100 .

* 3 MICS Indicator TC.49c - Mother's support for learning.
compute ind64sum = (EC5AA='A') +
                   (EC5BA='A') +
                   (EC5CA='A') +
                   (EC5DA='A') +
                   (EC5EA='A') +
                   (EC5FA='A') .

compute ind64 = (ind64sum >= 4) * 100 .
compute none=0.
if ind62sum=0 none=100.
variable labels none "Percentage of children with whom no adult household member have engaged in any activity".

* labeling variables for table heading.
variable labels
  ind62  "Percentage of children with whom adult household members have engaged in four or more activities [1]"
 /ind62sum "Mean number of activities with adult household members"
 /ind63  "Percentage of children with whom fathers have engaged in four or more activities [2]"
 /ind63sum "Mean number of activities with fathers"
 /ind64  "Percentage of children with whom mothers have engaged in four or more activities [3]"
 /ind64sum "Mean number of activities with mothers".

* Generate total.
compute total = 1.
compute totchild = 1.
compute tot2 = 1.
compute tot3 = 1.
compute tot4 = 1.
if (hl14>0) tot64 = 1 .
variable labels total "Total".
value labels tot4 1 "Percentage of children living with their".

value labels totchild 1 "Number of children age 2-4 years".

value labels felevel
0 "Pre-primary or none"
1 "Primary"
2 "Lower secondary"
3 "Upper secondary+"
7 "Father not in the household"
9 "Missing".

variable labels melevel " Mother's education [A]".
variable labels cdisability "Functional difficulties".

variable labels UB2 "Age".
value labels UB2 2 "2" 3 "3" 4 "4".

compute layer1 = 0.
variable labels layer1 "".
value labels layer1 0 "Adult household members".
	
compute layer2 = 0.
variable labels layer2 "".				   
value labels layer2 0 "Father".

compute layer3 = 0.
variable labels layer3 "".
value labels layer3 0 "Mother".


* For labels in French uncomment commands below.
* variable labels
hl14 'Mre  '
/hl18 'Pre  '
/none "Pourcentage d'enfants avec lesquels aucun membre adulte du mnage n'a particip  une activit"
/ind62  "Pourcentage d'enfants avec qui un membre adulte du mnage s'est engag dans 4 ou plus activits [1]"
 /ind62sum "Nombre moyen d'activits avec un membre adulte du mnage"
 /ind63  "Pourcentage d'enfants avec qui le pre s'est engag dans 4 ou plus activits [2]"
 /ind63sum "Nombre moyen d'activits avec le pre"
 /ind64  "Pourcentage d'enfants avec qui la mre s'est engage dans 4 ou plus activits [3]"
 /ind64sum "Nombre moyen d'activits avec la mre"
 /melevel " Instruction de la mre [A]"
 /cdisability "Difficults fonctionnelles".
* value labels 
totchild 1 "Nombre d'enfants de 2-4 ans"
/layer1 0 "Adult household members"
/layer2 0 "Pre"
/layer3 0 "Mre"
/felevel
0 "Pre-primaire ou Nant"
1 "Primaire"
2 "Secondaire I"
3 "Secondaire II et plus"
7 "Pre pas dans le mnage"
9 "Manquant".

* For labels in Spanish uncomment commands below.
* variable labels
hl14 'Madre'
/hl18 'Padre'
/none "Porcentaje de nios con los que ningn adulto del hogar particip en alguna actividad"
/ind62  "Porcentaje de nios con los que miembros adultos del hogar participaron en cuatro actividades o ms [1]"
 /ind62sum "Nmero promedio de actividades con miembros adultos del hogar"
 /ind63  "Porcentaje de nios con los que sus padres participaron en cuatro actividades o ms [2]"
 /ind63sum "Nmero promedio de actividades con los padres"
 /ind64  "Porcentaje de nios con los que sus madres participaron en cuatro actividades o ms [3]"
 /ind64sum "Nmero promedio de actividades con los madres"
/melevel " Educacin de la madre [A]"
 /cdisability "Dificultades funcionale".
* value labels 
totchild 1 "Nmero de nios de 2-4 aos"
/layer1 0 "Adult household members"
/layer2 0 "Padre"
/layer3 0 "Madre"
/felevel
0 "Pre-primaria o ninguna"
1 "Primaria"
2 "Secundaria I +"
3 "Secundaria II +"
7 "El padre biolgico no est en el hogar"
9 "Ignorado".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = tot2 tot3 tot4 tot64 total totchild layer1 layer2 layer3 display = none
  /table  total[c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + UB2 [c]
        + melevel [c]
        + felevel [c]
        + cdisability [c]
        + ethnicity [c]
        + windex5[c]
   by
          layer1 [c] > (ind62  [s] [mean f5.1]
        + ind62sum [s] [mean f5.1]
        + none [s] [mean f5.1])
        + tot4[c] > ( 
           hl18 [s] [mean f5.1] + hl14 [s] [mean f5.1] )
        + layer2 [c] > (ind63 [s] [mean f5.1]
        + ind63sum [s] [mean f5.1])
        + layer3 [c] > (ind64 [s] [mean f5.1]
        + ind64sum [s] [mean f5.1])
        + totchild [c] [count f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels visible=no
  /titles title=
    "Table TC.10.1: Support for learning"
    "Percentage of children age 2-4 years with whom adult household members engaged in activities that promote learning and school "
    "readiness during the last three days, and engagement in such activities by fathers and mothers, " + surveyname
   caption=
    "[1] MICS indicator TC.49a - Early stimulation and responsive care by any adult household member"
    "[2] MICS Indicator TC.49b - Early stimulation and responsive care by father"
    "[3] MICS Indicator TC.49c - Early stimulation and responsive care by mother"
    "[A] In this table and throughout the report, mother's education refers to educational attainment of mothers as well as caretakers of children under 5, "
    "who are the respondents to the under-5 questionnaire if the mother is deceased or is living elsewhere"											
    "na: not applicable"  .


* Ctables command in French.
* ctables
  /vlabels variables = tot2 tot3 tot4 tot64 total totchild layer1 layer2 layer3 display = none
  /table  total[c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + UB2 [c]
        + melevel [c]
        + felevel [c]
        + cdisability [c]
        + ethnicity [c]
        + windex5[c]
   by
          layer1 [c] > (ind62  [s] [mean f5.1]
        + ind62sum [s] [mean f5.1]
        + none [s] [mean f5.1])
        + tot4[c] > ( 
           hl18 [s] [mean f5.1] + hl14 [s] [mean f5.1] )
        + layer2 [c] > (ind63 [s] [mean f5.1]
        + ind63sum [s] [mean f5.1])
        + layer3 [c] > (ind64 [s] [mean f5.1]
        + ind64sum [s] [mean f5.1])
        + totchild [c] [count f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels visible=no
  /titles title=
    "Tableau TC.10.1: Soutien  l'apprentissage"
    "Pourcentage d'enfants de 2-4 years avec qui un membre adulte du mnage s'est engag dans des activits de promotion dapprentissage "+
	"et de prparation scolaire dans les 3 derniers jours et engagement dans de telles activits du pre et de la mre biologique, " + surveyname
   caption=
    "[1] Indicateur MICS TC.49a - Stimulation prcoce et soins ractifs de tout membre adulte du mnage"
    "[2] Indicateur MICS TC.49b - Stimulation prcoce et prise en charge ractive par le pre"
    "[3] Indicateur MICS TC.49b - Stimulation prcoce et prise en charge ractive par la mre"
    "[A] Dans ce tableau et tout au long du rapport, l'ducation de la mre se rfre au niveau de scolarit des mres ainsi que des tuteurs des enfants de moins de 5 ans, "+
	"qui sont les rpondants au questionnaire des moins de 5 ans si la mre est dcde ou vit ailleurs."											
    "na: n'est pas applicable"  .
	

* Ctables command in Spanish.
* ctables
  /vlabels variables = tot2 tot3 tot4 tot64 total totchild layer1 layer2 layer3 display = none
  /table  total[c]
        + hl4 [c]
        + hh6 [c]
        + hh7 [c]
        + UB2 [c]
        + melevel [c]
        + felevel [c]
        + cdisability [c]
        + ethnicity [c]
        + windex5[c]
   by
          layer1 [c] > (ind62  [s] [mean f5.1]
        + ind62sum [s] [mean f5.1]
        + none [s] [mean f5.1])
        + tot4[c] > ( 
           hl18 [s] [mean f5.1] + hl14 [s] [mean f5.1] )
        + layer2 [c] > (ind63 [s] [mean f5.1]
        + ind63sum [s] [mean f5.1])
        + layer3 [c] > (ind64 [s] [mean f5.1]
        + ind64sum [s] [mean f5.1])
        + totchild [c] [count f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels visible=no
  /titles title=
    "Tabla TC.10.1: Apoyo al aprendizaje"
    "Porcentaje de nios/as de 2 a 4 aos con los que un miembro adulto del hogar particip en actividades que promueven el aprendizaje y la preparacin para la escuela durante los tres ltimos das, "+
	"y la participacin en estas actividades por parte de los padres y madres, " + surveyname
   caption=
    "[1] MICS indicador TC.49a - Estimulacin temprana y cuidado afectuoso por parte de cualquier miembro adulto del hogar"
    "[2] MICS Indicador TC.49b - Estimulacin temprana y cuidado afectuoso por parte del padre"
    "[3] MICS Indicador TC.49c - Estimulacin temprana y cuidado afectuoso por parte de la madre"
    "[A] En esta tabla y en todo el informe, la educacin de la madre se refiere a los logros educativos de las madres as como de las/los cuidadoras/es de nios menores de 5 aos, "+
	"que responden al cuestionario para menores de 5 aos si la madre ha fallecido o est viviendo en otra parte"											
    "na: no aplicable"  .

new file.

erase file = 'tmp.sav'.