* Encoding: windows-1252.
 * Advice or treatment: CA5.

 * Public are CA6[A-H], Private are CA6[I-O], and Other are CA6[P-R] and [X].
 * Community health providers are CA6[D-E] and [L-M].
 * Health facilities or providers are CA6[A-J], [L-O] and [W].

 * In this table, percentages of children for whom advice or treatment was sought will not add to 100 since for some advice or treatment may have been sought from more than one type of provider.

 * The denominator for this table is number of children with diarrhoea during the last two weeks: CA1=1.					

***********************.

* Call include file for the working directory and the survey name.
include "surveyname.sps".

* Open children data file.
get file = 'ch.sav'.

select if (UF17 = 1).

weight by chweight.

* Diarrhoea.
recode CA1 (1 = 100) (else = 0) into diarrhea.
variable labels diarrhea "An episode of diarrhoea".

do if (diarrhea = 100).

* Advice or treatment: CA5.
+ recode CA5 (1 = 0) (else = 100) into advice.

* Public sector CA6[A-H]
*	Government hospital		A
*	Government health centre	B
*	Government health post		C
*	Community health worker	D
*	Mobile / Outreach clinic		E
*	Other public medical (specify)	H.

* Private medical sector CA6[I-O]
*	Private hospital / clinic		I
*	Private physician		J
*	Private pharmacy 		K
*	Community health worker
                             (non governement)	L
*	Mobile clinic 		M
*	Other private medical (specify)	O

*Other source CA6[P-X]
*	Relative / Friend		P
*	Shop / Market / Street 		Q
*	Traditional practitioner 		R

*Other (specify)			X.


* Public are CA6[A-H].
+ compute public = 0.
+ if (CA6A = "A" or CA6B = "B" or CA6C = "C" or  CA6D = "D" or  CA6E = "E" or CA6H = "H") public = 100. 

* Private are CA6 [I-O], including private pharmacy.
+ compute private = 0.
+ if (CA6I = "I" or CA6J = "J" or CA6K = "K" or CA6L = "L" or CA6M = "M" or CA6O = "O") private = 100. 

* Other are CA6[P-X].
+ compute others = 0.
+ if (CA6P = "P" or CA6Q = "Q" or CA6R = "R" or CA6X = "X") others = 100. 

* Community health providers are CA6[D-E] and [L].
+ compute comunityhp = 0.
+ if (CA6D = "D" or CA6E = "E"  or CA6L = "L" or CA6M = "M") comunityhp = 100. 

* Health facilities or providers are CA6[A-J] and [L-O] (private pharmacy not included).
+ compute anyhealth = 0.
+ if (CA6A = "A" or CA6B = "B" or CA6C = "C" or CA6D = "D" or CA6E = "E"  or CA6H = "H" or CA6I = "I" or CA6J = "J" or 
      CA6L = "L" or CA6M = "M" or CA6O = "O" or CA6W = "W") anyhealth = 100.

+ compute dtotal = 1.

end if.

compute layer = 0.
variable labels layer "".
value labels layer 0 "Percentage of children with diarrhoea for whom:".

compute layer1 = 0.
variable labels layer1 "".
value labels layer1 0 "Advice or treatment was sought from:".

compute layer2 = 0.
variable labels layer2 "".
value labels layer2 0 "Health facilities or providers".

variable labels  advice "No advice or treatment sought".
variable labels  public "Public".
variable labels  private "Private".
variable labels  comunityhp "Community health provider [A]".
variable labels  others "Other source".
variable labels  anyhealth "A health facility or provider [1] [B]".

variable labels  dtotal "".
value labels dtotal 1 "Number of children age 0-59 months with diarrhoea in the last two weeks".

compute tot = 1.
variable labels  tot "".
value labels tot 1 "Total".

* For labels in French uncomment commands below.
* variable labels
	 advice "Pas de conseils ou de traitement recherchs"
    /public "Publics"
    /private "Privs"
    /comunityhp "Agent de sant communautaire [A]"
    /others "Autre source"
    /anyhealth "Un tablissement de sant ou un prestataire de sant [1] [B]".
* value labels 
     layer 0 "Pourcentage d'enfants avec diarrhe pour qui:"
	/layer1 0 "Un conseil ou un traitement a t recherch auprs de:"
	/layer2 0 "Etablissement de sant ou prestataires de sant:"
	/dtotal 1 "Nombre d'enfants gs de 0-59 mois avec diarrhe dans les deux dernires semaines".

* For labels in Spanish uncomment commands below.
* variable labels
	 advice "No se solicit asesoramiento o tratamiento"
    /public "Pblicos"
    /private "Privados"
    /comunityhp "Proveedor de salud comunitaria [A]"
    /others "Otras fuentes"
    /anyhealth "Un centro de salud o proveedor [1] [B]".
* value labels 
     layer 0 "Porcentaje de nios con diarrea para quienes:"
	/layer1 0 "Asesoramiento o tratamiento fue solicitado en:"
	/layer2 0 "Centros de salud o proveedores:"
	/dtotal 1 "Nmero de nios de 0-59 meses con diarrea en las ltimas dos semanas".


* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = tot layer layer1 layer2 dtotal 
         display = none
  /table  tot [c]
          + HL4 [c] 
         + hh6 [c] 
         + hh7 [c] 
         + CAGE_11 [c] 
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]    by 
                  layer [c] > (layer1 [c] > (layer2 [c] > (public [s] [mean '' f5.1] + private [s] [mean '' f5.1] + comunityhp [s] [mean '' f5.1] ) +
                                    others [s] [mean '' f5.1] + anyhealth [s] [mean '' f5.1]) + 
                   	advice [s] [mean '' f5.1])+ dtotal[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
  "Table TC.3.1: Care-seeking during diarrhoea"
 	 "Percentage of children age 0-59 months with diarrhoea in the last two weeks for whom advice or treatment was sought, by source of advice or treatment, "
                   + surveyname
  caption =
  	"[1] MICS indicator TC.12 - Care-seeking for diarrhoea"		
                  "[A] Community health providers includes both public (Community health worker and Mobile/Outreach clinic) and private (Non-Government community health worker and Mobile clinic) health facilities"
                  "[B] Includes all public and private health facilities and providers, as well as those who did not know if public or private. Excludes private pharmacy".					

* Ctables command in French.
* ctables
  /vlabels variables = tot layer layer1 layer2 dtotal 
         display = none
  /table  tot [c]
          + HL4 [c] 
         + hh6 [c] 
         + hh7 [c] 
         + CAGE_11 [c] 
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]    by 
                  layer [c] > (layer1 [c] > (layer2 [c] > (public [s] [mean '' f5.1] + private [s] [mean '' f5.1] + comunityhp [s] [mean '' f5.1] ) +
                                    others [s] [mean '' f5.1] + anyhealth [s] [mean '' f5.1]) + 
                   	advice [s] [mean '' f5.1])+ dtotal[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
  "Tableau TC.3.1: Recherche de traitement durant la diarrhe"
  "Pourcentage d'enfants gs de 0-59 mois avec diarrhe dans les deux dernires semaines pour qui un conseil ou un traitement a t recherch, selon la source du conseil ou traitement, "
                   + surveyname
  caption =
  	"[1]  Indicateur MICS TC.12 - Recherche de soins pour diarrhe"		
                  "[A] Agent de sant communautaire inclut,  la fois, les prestataires de sant de sant publics (Agent de sant communautaire, Clinique mobile ou de stratgie avance) et prive (Clinique mobile) des tablissemdents de sant"
                  "[B] Comprend tous les tablissements de sant publics et privs et les fournisseurs, ainsi que ceux qui ne savaient pas si public ou priv. Exclut la pharmacie prive".					

* Ctables command in Spanish.
* ctables
  /vlabels variables = tot layer layer1 layer2 dtotal 
         display = none
  /table  tot [c]
          + HL4 [c] 
         + hh6 [c] 
         + hh7 [c] 
         + CAGE_11 [c] 
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]    by 
                  layer [c] > (layer1 [c] > (layer2 [c] > (public [s] [mean '' f5.1] + private [s] [mean '' f5.1] + comunityhp [s] [mean '' f5.1] ) +
                                    others [s] [mean '' f5.1] + anyhealth [s] [mean '' f5.1]) + 
                   	advice [s] [mean '' f5.1])+ dtotal[c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
  "Tabla TC.3.1: Bsqueda de atencin durante la diarrea"
 	 "Porcentaje de nios de 0-59 meses con diarrea en las ltimas dos semanas para quienes se solicit asesoramiento o tratamiento, por fuente de asesoramiento o tratamiento, "
                   + surveyname
  caption =
  	"[1] MICS indicador TC.12 - Bsqueda de atencin durante la diarrea"		
    "[A] Proveedores de salud comunitaria incluye instalaciones de salud tanto pblicas (Trabajadores de salud comunitaria y clnicas mviles) como privadas (Trabajador de salud comunitario no gubernamental y clnicas mviles)"
    "[B] Incluye todas las instalaciones y proveedores  pblicos y privados, pero excluye las farmacias privadas".				
		
new file.
