* Encoding: windows-1252.
 * "Households that use clean fuels and technologies for cooking (EU1=01, 02, 03, 04, 05, or (EU1=06 and EU4=01)).
 * Note: A liquid fuel stove (EU1=06) is considered clean if used with ethanol/alcohol (EU4=01)

 * Households that use solid fuels for cooking ((EU1=07, 08, 09, or 96) and (EU1=06 and EU4 <> (01, 02, 03))) as the main type of fuel used for cooking.

 * Denominators are obtained by weighting the number of households by the number of household members (HH48)."																		

***.

* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'hh.sav'.

select if (HH46  = 1).

compute hhweightHH48 = HH48*hhweight.

weight by hhweightHH48.

compute nhhmem = 1.
variable labels  nhhmem "Number of household members".
value labels nhhmem 1 " ".

compute cleanfuels=0.
if ((any (EU1, 1,2,3,4,5) ) or (EU1=6 and EU4=1)) cleanfuels=100.
variable labels cleanfuels "Clean fuels and technologies [1]".


compute alcohol=0.
if cleanfuels=0 and EU4=1  alcohol=100.
variable labels alcohol "Alcohol/ Ethanol".

compute gasoline=0.
if cleanfuels=0 and EU4=2  gasoline=100.
variable labels gasoline "Gasoline/ Diesel".

compute kerosene=0.
if cleanfuels=0 and EU4=3  kerosene=100.
variable labels kerosene "Kerosene/ Paraffin".

compute coal=0.
if cleanfuels=0 and EU4=4  coal=100.
variable labels coal "Coal/ Lignite".

compute charcoal=0.
if cleanfuels=0 and EU4=5  charcoal=100.
variable labels charcoal "Charcoal".

compute wood=0.
if cleanfuels=0 and EU4=6  wood=100.
variable labels wood "Wood".

compute crop=0.
if cleanfuels=0 and EU4=7  crop=100.
variable labels crop "Crop residue / Grass/ Straw/ Shrubs".

compute animaldung=0.
if cleanfuels=0 and EU4=8  animaldung=100.
variable labels animaldung "Animal dung/ waste".

compute pbiomass=0.
if cleanfuels=0 and EU4=9 pbiomass=100.
variable labels pbiomass "Processed biomass (pellets) or woodchips".

compute garbage=0.
if cleanfuels=0 and EU4=10  garbage=100.
variable labels garbage "Garbage/ Plastic".

compute sawdust=0.
if cleanfuels=0 and EU4=11  sawdust=100.
variable labels sawdust "Sawdust".

compute other=0.
if cleanfuels=0 and EU4=96  other=100.
variable labels other "Other fuel for cooking".

compute nofood=0.
if EU1=97 nofood=100.
variable labels nofood "No food cooked in the household".

compute EU4missing=0.
if EU4=99 EU4missing=100.
variable labels EU4missing "Missing".

compute solidftech=0.
if (charcoal = 100 or wood = 100 or crop = 100 or animaldung = 100 or pbiomass = 100 or garbage = 100 or sawdust = 100) solidftech=100.
variable labels solidftech "Solid fuels and technology for cooking".

compute layer1 = 0.
value labels layer1 0 "Percentage of household members in households with primary reliance on:".

compute layer2 = 0.
value labels layer2 0 "Solid fuels for cooking".

compute total = 1.
variable labels  total "Total".
value labels total 1 " ".

compute total100 = 100.
variable labels  total100 "Total".
value labels total100 100 " ".

* For labels in French uncomment commands below.
* variable labels
    nhhmem "Nombre de membres du mnage"
   /cleanfuels "Combustibles propres et technologies [1]"
   /alcohol "Alcool / thanol"
   /gasoline "Essence / Diesel"
   /kerosene "Krosne / Paraffine"
   /coal "Charbon/ Lignite"
   /charcoal "Charbon"
   /wood "Bois"
   /crop "Rsidus agricoles / herbes /pailles / arbustes"
   /animaldung "Bouse danimaux / dchets"
   /pbiomass "Biomasse manufacture (granules) ou copeaux de bois"
   /garbage "Ordures / plastique"
   /sawdust "Sciure"
   /other "Autre carburant pour la cuisson"
   /nofood "Aucune nourriture cuisine dans le mnage"
   /EU4missing "Manquant"
   /solidftech "Combustibles solides et technologie pour la cuisson".
* value labels 
    layer1 0 "Pourcentage des membres du mnage dans les mnages qui comptent principalement sur:
   /layer2 0 "Combustibles solides pour la cuisson".

* For labels in Spanish uncomment commands below.
* variable labels
    nhhmem "Nmero de miembros del hogar"
   /cleanfuels "Combustibles y tecnologas limpios [1]"
   /alcohol "Alcohol/ Etanol"
   /gasoline "Gasolina/Diesel"
   /kerosene "Queroseno/Parafina"
   /coal "Carbn/ Lignito"
   /charcoal "Carbn vegetal"
   /wood "Madera"
   /crop "Paja/ arbustos/hierba"
   /animaldung "Estircol animal"
   /pbiomass "Biomasa procesada (grnulos) o astillas de madera"
   /garbage "Basura/ Plstico"
   /sawdust "Serrn"
   /other "Otro combustible para cocinar"
   /nofood "No se cocina comida en el hogar"
   /EU4missing "Ignorado"
   /solidftech "Combustibles y tecnologa contaminantes para cocinar".
* value labels 
    layer1 0 "Porcentaje de miembros del hogar en hogares que dependen principalmente de:"
   /layer2 0 "Combustibles slidos para cocinar".   
   
* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = layer1 layer2
           display = none
  /table   total [c]
         + HH6 [c]  
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
          layer1 [c] > ((cleanfuels [s] [mean '' f5.1] + alcohol [s] [mean '' f5.1] + gasoline [s] [mean '' f5.1] + kerosene [s] [mean '' f5.1] ) +
             layer2 [c] > (coal [s] [mean '' f5.1]
             + charcoal [s] [mean '' f5.1]  
             + wood [s] [mean '' f5.1]  
             + crop [s] [mean '' f5.1]  
             + animaldung [s] [mean '' f5.1]  
             + pbiomass [s] [mean '' f5.1]  
             + garbage [s] [mean '' f5.1]  
             + sawdust [s] [mean '' f5.1]  ))
             + other [s] [mean '' f5.1]  
             + nofood [s] [mean '' f5.1]  
             + EU4missing [s] [mean '' f5.1]  
         + total100 [s] [mean '' f5.1] 
         + solidftech [s] [mean '' f5.1] 
         + nhhmem [s] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
    "Table TC.4.2: Primary reliance on solid fuels for cooking"
    "Percentage of household members living in households using clean fuels and technology for cooking and percent distribution of household members " + 
   "using polluting fuels and technologies for cooking according to type of cooking fuel mainly used by the household, and percentage of household members " + 
    "living in households using polluting fuels and technologies for cooking, " + surveyname
 caption=
    "[1] MICS indicator TC.15 - Primary reliance on clean fuels and technologies for cooking".
  
   
* Ctables command in French.
* ctables
  /vlabels variables = layer1 layer2
           display = none
  /table   total [c]
         + HH6 [c]  
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
          layer1 [c] > ((cleanfuels [s] [mean '' f5.1] + alcohol [s] [mean '' f5.1] + gasoline [s] [mean '' f5.1] + kerosene [s] [mean '' f5.1] ) +
             layer2 [c] > (coal [s] [mean '' f5.1]
             + charcoal [s] [mean '' f5.1]  
             + wood [s] [mean '' f5.1]  
             + crop [s] [mean '' f5.1]  
             + animaldung [s] [mean '' f5.1]  
             + pbiomass [s] [mean '' f5.1]  
             + garbage [s] [mean '' f5.1]  
             + sawdust [s] [mean '' f5.1]  ))
             + other [s] [mean '' f5.1]  
             + nofood [s] [mean '' f5.1]  
             + EU4missing [s] [mean '' f5.1]  
         + total100 [s] [mean '' f5.1] 
         + solidftech [s] [mean '' f5.1] 
         + nhhmem [s] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
    "Tableau TC.4.2: Recours primaire aux carburants propres et aux technologies de cuisson"
    "Pourcentage des membres des mnages vivant dans des mnages utilisant des combustibles et technologies propres pour cuisiner "+
	"et pourcentage des membres du mnage utilisant des carburants et technologies polluants pour cuisiner selon le type de combustible utilis principalement par le mnage, "+
	"et pourcentage des membres du mnage vivant dans des mnages utilisant des carburants polluants et technologies pour cuisiner,  " + surveyname
 caption=
    "[1] Indicateur MICS TC.15 - Recours primaire aux carburants propres et aux technologies de cuisson".
   
* Ctables command in Spanish.
* ctables
  /vlabels variables = layer1 layer2
           display = none
  /table   total [c]
         + HH6 [c]  
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
          layer1 [c] > ((cleanfuels [s] [mean '' f5.1] + alcohol [s] [mean '' f5.1] + gasoline [s] [mean '' f5.1] + kerosene [s] [mean '' f5.1] ) +
             layer2 [c] > (coal [s] [mean '' f5.1]
             + charcoal [s] [mean '' f5.1]  
             + wood [s] [mean '' f5.1]  
             + crop [s] [mean '' f5.1]  
             + animaldung [s] [mean '' f5.1]  
             + pbiomass [s] [mean '' f5.1]  
             + garbage [s] [mean '' f5.1]  
             + sawdust [s] [mean '' f5.1]  ))
             + other [s] [mean '' f5.1]  
             + nofood [s] [mean '' f5.1]  
             + EU4missing [s] [mean '' f5.1]  
         + total100 [s] [mean '' f5.1] 
         + solidftech [s] [mean '' f5.1] 
         + nhhmem [s] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
    "Tabla TC.4.2: Dependencia principal en combustibles slidos para cocinar"
    "Porcentaje de miembros de hogares que viven en hogares que utilizan combustibles y tecnologas limpios para cocinar "+
	"y distribucin porcentual de miembros del hogar que utilizan combustibles y tecnologas contaminantes para cocinar de acuerdo con el tipo de combustible para cocinar "+
	"usado principalmente en el hogar y el porcentaje de miembros del hogar que viven en hogares que usan combustibles y tecnologas contaminantes para cocinar,  " + surveyname
 caption=
    "[1] MICS indicador TC.15 - Dependencia principal en combustibles y tecnologas limpios para cocinar".

new file.