* Encoding: windows-1252.
 * "Households that use polluting fuels and technology for cooking ((EU1=07, 08, 09, or 96) and (EU1=06 and EU4<>01)) as the main type of fuel used for cooking and 
  in poorly ventilated locations (EU5=1 or 2 and EU2=2)

 * Denominators are obtained by weighting the number of households by the number of household members (HH48)."													
																	

***.

* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'hh.sav'.

select if (HH46  = 1).

compute hhweightHH48 = HH48*hhweight.

weight by hhweightHH48.

compute nhhmem = 1.
variable labels  nhhmem "Number of household members".
value labels nhhmem 1 " ".

compute pollutingfuels=0.
if ((any (EU1, 7, 8, 9, 96) ) or (EU1=6 and EU4<>1)) pollutingfuels=100.
variable labels pollutingfuels "Percentage of household members in households with primary reliance on polluting fuels and technology for cooking".
	
compute chimney=0.
if EU2=1 chimney=100.
variable labels chimney "Chimney". 

compute fan=0.
if EU3=1 fan=100.
variable labels fan "Fan".

do if pollutingfuels=100.
+ compute cookingplace=EU5.
end if.

variable labels cookingplace "Place of cooking is:".
value labels cookingplace 1 "In main house: No separate room" 2 "In main house: In a separate room" 
                                        3 "In a separate building"
                                        4 "Outdoors: Open air" 5 "Outdoors: On veranda or covered porch"
                                        6 "Other place" 9 "Missing".

do if pollutingfuels=100.
+ compute numpollutingfuels=1.
+ compute pollutingpoorvent=0.
+ if ((any (EU5, 1, 2)) and EU2=2) pollutingpoorvent=100.
end if.

variable labels pollutingpoorvent "Percentage of household members cooking with polluting fuels and technology in poorly ventilated locations" .
variable labels numpollutingfuels "Number of household members in households using polluting fuels and technology for cooking".
	

compute layer1 = 0.
value labels layer1 0 "Percentage of household members cooking with polluting fuels and:".

compute layer2 = 0.
value labels layer2 0 "Cookstove has".

compute total = 1.
variable labels  total "Total".
value labels total 1 " ".

compute total100 = 100.
variable labels  total100 "Total".
value labels total100 100 " ".

* For labels in French uncomment commands below.
* variable labels
     nhhmem "Nombre de membres du mnage"
	/pollutingfuels "Pourcentage des membres du mnage dans les mnages ayant une dpendance primaire aux carburants polluants et  la technologie pour cuisiner"
	/chimney "Chemine " 
	/fan "Ventilateur "
	/cookingplace "Lieu de cuisson est:"
    /pollutingpoorvent "Pourcentage des membres du mnage cuisinant avec des carburants polluants et de la technologie dans des endroits mal ventils" 
    /numpollutingfuels "Nombre de membres du mnage dans les mnages utilisant des carburants et des technologies polluants pour cuisiner".
* value labels 
     layer1 0 "Pourcentage de membres du mnage cuisinant avec des carburants polluants et"
	/layer2 0 "La cuisinire a"
	/cookingplace 1 "Dans la maison principale: Pas de pice spare" 2 "Dans la maison principale: Dans une pice spare" 
                                        3 "Dans un btiment spar"
                                        4 "Dehors: En plein air" 5 "Dehors: sur une veranda ou un porche couvert"
                                        6 "Autre place" 9 "Manquant".

* For labels in Spanish uncomment commands below.
* variable labels
     nhhmem "Nmero de miembros del hogar"
	/pollutingfuels "Porcentaje de miembros del hogar en hogares con dependencia principal en combustibles y tecnologa contaminantes para cocinar"
	/chimney "Chimenea" 
	/fan "Ventilador"
	/cookingplace "El  lugar para cocinar est:"
    /pollutingpoorvent "Porcentaje de miembros del hogar que cocinan con combustibles y tecnologa contaminantes en lugares con poca ventilacin" 
    /numpollutingfuels "Nmero de miembros del hogar en hogares que usan combustibles y tecnologa contaminantes para cocinar".
* value labels 
     layer1 0 "Porcentaje de miembros del hogar que cocinan con combustibles contaminantes y:"
	/layer2 0 "La estufa tiene"
	/cookingplace 1 "En la casa principal: Sin habitacin separada" 2 "En la casa principal: En una habitacin separada" 
                                        3 "En un edificio separado"
                                        4 "Al aire libre: Espacio abierto" 5 "Al aire libre: En la terraza o porche cubierto"
                                        6 "En otro  lugar" 9 "Ignorado.
										
* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = layer1 layer2
           display = none
  /table   total [c]
         + HH6 [c]
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
             pollutingfuels [s] [mean '' f5.1]  
             + nhhmem [s] [count '' f5.0]             
             +  layer1 [c] > ((layer2 [c] > (chimney [s] [mean '' f5.1] + fan [s] [mean '' f5.1] ) )
             + cookingplace [c] [rowpct.validn '' f5.1] + total100 [s] [mean '' f5.1] )
             + pollutingpoorvent [s] [mean '' f5.1]  
             + numpollutingfuels [s] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
    "Table TC.4.3:  Polluting fuels and technologies for cooking by type and characteristics of cookstove and place of cooking"
    "Percent distribution of household members in households using polluted fuels for cooking by type and characteristics of cookstove and by place of cooking,  " + surveyname.
      										
* Ctables command in French.
* ctables
  /vlabels variables = layer1 layer2
           display = none
  /table   total [c]
         + HH6 [c]
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
             pollutingfuels [s] [mean '' f5.1]  
             + nhhmem [s] [count '' f5.0]             
             +  layer1 [c] > ((layer2 [c] > (chimney [s] [mean '' f5.1] + fan [s] [mean '' f5.1] ) )
             + cookingplace [c] [rowpct.validn '' f5.1] + total100 [s] [mean '' f5.1] )
             + pollutingpoorvent [s] [mean '' f5.1]  
             + numpollutingfuels [s] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
    "Tableau TC.4.3: Combustibles polluants et technologies de cuisson selon le type et les caractristiques de la cuisinire et du lieu de cuisson"
    "Rpartition en pourcentage des membres du mnage dans les mnages utilisant des combustibles pollus pour cuisiner selon le type et les caractristiques du foyer et selon le lieu de cuisson, " + surveyname.
        										
* Ctables command in Spanish.
* ctables
  /vlabels variables = layer1 layer2
           display = none
  /table   total [c]
         + HH6 [c]
         + HH7 [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c]
   by 
             pollutingfuels [s] [mean '' f5.1]  
             + nhhmem [s] [count '' f5.0]             
             +  layer1 [c] > ((layer2 [c] > (chimney [s] [mean '' f5.1] + fan [s] [mean '' f5.1] ) )
             + cookingplace [c] [rowpct.validn '' f5.1] + total100 [s] [mean '' f5.1] )
             + pollutingpoorvent [s] [mean '' f5.1]  
             + numpollutingfuels [s] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title = 
    "Tabla TC.4.3: Combustibles y tecnologas contaminantes para cocinar por tipo y caractersticas de la estufa y el lugar para cocinar"
    "Distribucin porcentual de los miembros del hogar en hogares que utilizan combustibles contaminantes para cocinar por tipo y caractersticas de la estufa y por lugar para cocinar,  " + surveyname.

new file.