* Encoding: windows-1252.
 * TN15 in the Insecticide Treated Nets module is used to determine if a household member has slept under any of the nets in the household. 

 * The first denominator of the table includes all household members who have stayed in the household the previous night (HL7=1).

 * Insecticide treated nets (ITN) are long lasting insecticidal treated nets (TN5=11-18).			


* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = "tn.sav".

sort cases by HH1 HH2.

compute itnh = 0.
if (TN5 >=11 and TN5 <= 18) itnh = 1.
variable labels  itnh "Percentage of households with at least one ITN".

aggregate outfile = "tmp1.sav"
  /break=HH1 HH2
  /itnh = max (itnh).

get file = 'hl.sav'.

recode HL6 (0 thru 4 = 1) (5 thru 14 = 2) (15 thru 34 = 3) (35 thru 49 = 4) (50 thru 96 = 5) (97 thru hi = 9) into memage.
variable labels memage "Age".
value labels memage
	1 "0-4"
	2 "5-14"
	3 "15-34"
	4 "35-49"
	5 "50+"
	9 "DK/Missing".

sort cases by HH1 HH2 HL1.

match files 
  /file=*
  /table='tmp1.sav'
  /by hh1 hh2.

weight by hhweight.

select if (HL7 = 1).

compute total = 1.
value labels total  1 "Number of household members who spent the previous night in the interviewed households".
variable labels  total "".

* Any mosquito net.
compute netpresent = 0.
if (TN13 = 1) netpresent = 100.

*Insecticide treated nets (ITN) are long lasting treated nets (TN5=11-18).
compute itn = 0.
if (TN5 >=11 and TN5 <= 18) itn = 100.

compute layer = 0.
variable labels layer "".
value labels layer 0 "Percentage of household members who the previous night slept under:".

variable labels  netpresent "Any mosquito net".
variable labels  itn "An insecticide treated net (ITN) [1] [A]".

do if (itnh > 0).

+ compute itnsl = 0.
+ if (itn = 100) itnsl = 100.

+ compute itnhtot = 1.
+ variable labels  itnhtot "".

end if.

variable labels  itnsl "Percentage who the previous night slept under an ITN".
value labels itnhtot 1 "Number of household members in households with at least one ITN".

compute tot = 1.
variable labels  tot "".
value labels tot 1 "Total".

* For labels in French uncomment commands below.
* variable labels
    memage "Age"
   /itn "Moustiquaire imprgne d'insecticide (MII) (ITN) [1] [A]"
   /netpresent "N'importe quelle moustiquaire "
   /itnsl "Pourcentage qui ont dormi sous MII la nuit dernire".
* value labels 
    total  1 "Nombre de membres des mnages  qui ont pass la nuit dernire dans les mnages enquts"
   /layer 0 "Pourcentage de membres des mnages qui ont dormi la nuit prcdente sous:"
   /itnhtot 1 "Nombre de membres des mnages dans les mnages qui ont au moins une MII"
   /memage
	1 "0-4"
	2 "5-14"
	3 "15-34"
	4 "35-49"
	5 "50+"
	9 "NSP/Manquant".

* For labels in Spanish uncomment commands below.
* variable labels
    memage "Edad"
   /itn "Un mosquitero tratado con insecticida (MIT) [1] [A]"
   /netpresent "Cualquier mosquitero"
   /itnsl "Porcentaje que la noche anterior durmi bajo un MTI".
* value labels 
    total  1 "Nmero de miembros del hogar que pasaron la noche anterior en los hogares entrevistados"
   /layer 0 "Porcentaje de miembros del hogar que la noche anterior durmieron bajo:"
   /itnhtot 1 "Nmero de miembros del hogar en hogares con al menos un MTI"
   /memage
	1 "0-4"
	2 "5-14"
	3 "15-34"
	4 "35-49"
	5 "50+"
	9 "NS/Ignorado".
	
* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables =  total tot itnhtot layer
         display = none
  /table tot [c]
         + hl4 [c]
         + HH6 [c]
         + HH7 [c]
         + memage [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c] by 
                  layer [c] > (netpresent [s] [mean '' f5.1] +  itn [s] [mean '' f5.1] ) +  total [c] [count '' f5.0] +
                  itnsl [s] [mean '' f5.1] + itnhtot [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
   "Table TC.6.5: Use of mosquito nets by the household population"
	"Percentage of household members who slept under a mosquito net last night, by type of net, " + surveyname
  caption=
   "[1] MICS indicator TC.22 - Population that slept under an ITN; SDG indicator 3.8.1"
   "[A] An insecticide-treated net (ITN) is a net treated at factory that does not require any further treatment. In previous surveys, this was known as a long-lasting insecticidal net (LLIN).".
												
* Ctables command in French.
* ctables
  /vlabels variables =  total tot itnhtot layer
         display = none
  /table tot [c]
         + hl4 [c]
         + HH6 [c]
         + HH7 [c]
         + memage [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c] by 
                  layer [c] > (netpresent [s] [mean '' f5.1] +  itn [s] [mean '' f5.1] ) +  total [c] [count '' f5.0] +
                  itnsl [s] [mean '' f5.1] + itnhtot [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
   "Tableau TC.6.5: Utilisation de moustiquaires par la population des mnages"
	"Pourcentage de membres des mnages qui ont dormi sous moustiquaire la nuit prcdente, selon le type de moustiquaire, " + surveyname
  caption=
   "[1] Indicateur MICS TC.22 - Population qui a dormi sous MII; Indicateur ODD 3.8.1"
   "[A] Moustiquaire imprgne d'insecticide (MII) est une moustiquaire traite en usine qui ne ncessite aucun traitement supplmentaire. Dans les enqutes prcdentes, il s'agissait d'une moustiquaire insecticide  longue dure d'action (MILD).".
			
* Ctables command in Spanish.
* ctables
  /vlabels variables =  total tot itnhtot layer
         display = none
  /table tot [c]
         + hl4 [c]
         + HH6 [c]
         + HH7 [c]
         + memage [c]
         + helevel [c]
         + ethnicity [c]
         + windex5 [c] by 
                  layer [c] > (netpresent [s] [mean '' f5.1] +  itn [s] [mean '' f5.1] ) +  total [c] [count '' f5.0] +
                  itnsl [s] [mean '' f5.1] + itnhtot [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
   "Tabla TC.6.5: Uso de mosquiteros por la poblacin del hogar"
	"Porcentaje de miembros del hogar que durmieron bajo de un mosquitero la noche anterior, por tipo de mosquitero, " + surveyname
  caption=
   "[1] MICS indicador TC.22 -Poblacin que durmi bajo un MTI; indicador ODS 3.8.1"
   "[A] Un mosquitero tratado con insecticida (MTI) es un mosquitero tratado en fbrica que no requiere ningn tratamiento adicional. " +
   "En encuestas anteriores, esto se conoca como mosquitero tratado con insecticida de larga duracin (LLIN). 'Otro' es un mosquitero que no es MTI.".
						
new file.

* erase working file.
erase file = "tmp1.sav".