* Encoding: windows-1252.
 * Intermittent Preventive Treatment (IPT) is defined as pregnant women who received at least 3 doses of SP/Fansidar (MN16=1 and MN17>=3).					

***********************.

include "surveyname.sps".

get file = 'wm.sav'.

select if (WM17 = 1).

weight by wmweight.

* Select women that gave birth in two years preceeding the survey.
select if (CM17 = 1).

compute total = 1.
value labels total 1 "Number of women age 15-49 years with a live birth in the last 2 years".
variable labels  total "".

include "define\MICS6 - 06 - TM.sps".

compute medicine=0.
if MN16=1 medicine=100.
variable labels medicine "Who took any medicine to prevent malaria".

compute sponce = 0.
if (MN16 = 1) sponce = 100.

compute spmore2 = 0.
if (MN16 = 1 and MN17 >= 2 and MN17 < 97) spmore2 = 100.

compute spmore3 = 0.
if (MN16 = 1 and MN17 >= 3 and MN17 < 97) spmore3 = 100.

compute spmore4 = 0.
if (MN16 = 1 and MN17 >= 4 and MN17< 97) spmore4 = 100.


variable labels  sponce "At least once".
variable labels  spmore2 "Two or more times".
variable labels  spmore3 "Three or more times [1]".
variable labels  spmore4 "Four or more times".

compute layer=0.
variable labels  layer "".
value labels layer 0 "Percentage of pregnant women:".
compute layer1=0.
variable labels  layer1 "".
value labels layer1 0 "who took SP/Fansidar:".

compute tot = 1.
variable labels  tot "".
value labels tot 1 "Total".

* For labels in French uncomment commands below.
* variable labels
       medicine "Qui ont pris des mdicaments pour prvenir le paludisme"
	  /sponce "Au moins une fois "
	  /spmore2 "Deux fois ou plus "
	  /spmore3 "Trois fois ou plus [1]"
	  /spmore4 "Quatre fois ou plus".
* value labels 
       total 1 "Nombre de femmes de 15-49 ans avec une naissance vivante dans les deux dernires annes"
	  /layer 0 "Pourcentage de femmes enceintes:"
	  /layer1 0 "qui ont pris SP/Fansidar:".
	  
* For labels in Spanish uncomment commands below.
* variable labels
       medicine "Que tomaron algn medicamento para prevenir la malaria"
	  /sponce "Al menos una"
	  /spmore2 "Dos veces o ms"
	  /spmore3 "Tres veces o ms [1]"
	  /spmore4 "Cuatro veces o ms".
* value labels 
       total 1 "Nmero de mujeres de 15-49 aos que tuvieron un nacido vivo en los dos ltimos aos"
	  /layer 0 "Porcentaje de mujeres embarazadas:
	  /layer1 0 "que tomaron SP/Fansidar:".


* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables =  total tot layer layer1
         display = none
  /table tot [c] 
         + HH6 [c]
         + HH7 [c]
         + welevel [c]
         + ethnicity [c]
         + windex5 [c]
        by 
                 layer[c] > (medicine [s][mean '' f5.1] +  layer1[c] > (sponce [s][mean '' f5.1] + spmore2 [s][mean '' f5.1] + spmore3 [s][mean '' f5.1] + spmore4 [s][mean '' f5.1]) )+
                total [c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
  "Table TC.6.9: Use of Intermittent Preventive Treatment for malaria (IPTp) by women during pregnancy"
	"Percentage of women age 15-49 years who had a live birth during the five years preceding the survey and who took intermittent preventive treatment (IPTp) for malaria during pregnancy, "+ surveyname
  caption =
    "[1]  MICS indicator TC.25 - Intermittent preventive treatment for malaria during pregnancy".								


* Ctables command in French.
* ctables
  /vlabels variables =  total tot layer layer1
         display = none
  /table tot [c] 
         + HH6 [c]
         + HH7 [c]
         + welevel [c]
         + ethnicity [c]
         + windex5 [c]
        by 
                 layer[c] > (medicine [s][mean '' f5.1] +  layer1[c] > (sponce [s][mean '' f5.1] + spmore2 [s][mean '' f5.1] + spmore3 [s][mean '' f5.1] + spmore4 [s][mean '' f5.1]) )+
                total [c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
  "Tableau TC.6.9: Traitement prventif intermittent du paludisme pour une femme pendant sa grossesse"
	"Pourcentage de femmes de 15-49 ans qui ont eu une naissance vivante dans les deux annes prcdant l'enqute et qui ont reu un traitement prventif intermittent (TPI) contre le paludisme, "+ surveyname
  caption =
    "[1] Indicateur MICS TC.25 - Traitement Prventif Intermittent du paludisme".								


* Ctables command in Spanish.
* ctables
  /vlabels variables =  total tot layer layer1
         display = none
  /table tot [c] 
         + HH6 [c]
         + HH7 [c]
         + welevel [c]
         + ethnicity [c]
         + windex5 [c]
        by 
                 layer[c] > (medicine [s][mean '' f5.1] +  layer1[c] > (sponce [s][mean '' f5.1] + spmore2 [s][mean '' f5.1] + spmore3 [s][mean '' f5.1] + spmore4 [s][mean '' f5.1]) )+
                total [c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
  "Tabla TC.6.9: Uso de tratamiento preventivo intermitente contra la malaria (IPTp) por mujeres durante el embarazo"
	"Nmero de mujeres de 15-49 aos de edad que tuvieron un nacido vivo en los dos aos previos a la encuesta y que tomaron el tratamiento preventivo intermitente (TPI) contra la malaria durante el embarazo, "+ surveyname
  caption =
    "[1] MICS indicador TC.25 - Tratamiento preventivo intermitente contra la malaria durante el embarazo".								

new file.
