* Encoding: windows-1252.
*V2. updated 7 September 2018.
* MICS6 TC-7.2.
 * Children are distributed by the responses to MN39A/B. 

 * Children consuming:
- milk-based liquids only are: MN39=A and/or G AND MN39<>(B, C, D, F, H, I, X)
- non-milk-based liquids/items only are: MN39=B, C, D, F, H, I and/or X AND MN39<>(A, G) 
- "both" are those consuming at least one milk-based liquid and at least one non-milk-based liquid/item:  MN39=A and/or G AND MN39=B, C, D, F, H, I and/or X.
 * - "any" are those consuming any milk-based liquid and  non-milk-based liquid/item: MN39=A, B, C, D, F, G, H, I or X


* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'wm.sav'.

include "CommonVarsWM.sps".

select if (WM17 = 1).

weight by wmweight.

include 'define\MICS6 - 06 - TM.sps' .

select if (CM17 = 1).

* Calculate months since last birth IF last birth in last five years.
compute monthsSinceLastBirth = wdoi - wdoblc.
variable labels monthsSinceLastBirth "Months since last birth".

*Create a recoded months variable since last birth.
recode monthsSinceLastBirth (0 thru 11 = 1)(12 thru 24 = 2) into monthsSinceLastBirthGroups.
variable labels monthsSinceLastBirthGroups "Months since last birth".
value labels monthsSinceLastBirthGroups 
1 " 0-11 months" 
2 "12-23 months".

compute everBreastfed = MN36.
variable labels everBreastfed "Breastfeeding status".
value labels everBreastfed
1 "Ever breastfed"
2 "Never breastfed"
9 "Missing".


compute layer = 1.
value labels layer 
1 "Percentage of children who consumed:".

compute otherLiquids = 1.
value labels  otherLiquids 
1 "Consumed other than breastmilk:".

compute milk = 0.
if (MN39A = "A") milk = 100.
variable labels milk "Milk (other than breastmilk)".

compute water = 0. 
if (MN39B = "B") water = 100.
variable labels water "Plain water".

compute sugar = 0.
if (MN39C = "C") sugar = 100.
variable labels sugar "Sugar or glucose water".

compute gripe = 0.
if (MN39D = "D") gripe = 100.
variable labels gripe "Gripe water".

compute fruit = 0.
if (MN39F = "F") fruit = 100.
variable labels fruit "Fruit juice".

compute formula = 0.
if (MN39G = "G") formula = 100.
variable labels formula "Infant formula".

compute tea = 0.
if (MN39H = "H") tea = 100.
variable labels tea "Tea/Infusions/Traditional herbal preparations".

compute honey = 0.
if (MN39I = "I") honey = 100.
variable labels honey "Honey".

compute ors=0.
if ((MN39E = "E" or MN39J = "J")) ors = 100.
variable labels ors "Prescribed medicine/ ORS/Sugar-salt solutions".

compute other = 0.
if (MN39X = "X") other = 100.
variable labels other "Other".


compute milkbased = 0.
if ((MN39A = "A" or MN39G = "G")  and (MN39B <> "B" and MN39C <> "C" and  MN39D <> "D" and MN39F <> "F" and  MN39H <> "H"  and MN39I <> "I" and  MN39X <> "X")) milkbased = 100.

compute nonmilkbased = 0.
if ((MN39A <> "A" and MN39G <> "G")  and (MN39B = "B" or MN39C = "C" or  MN39D = "D" or   MN39F = "F" or  MN39H = "H"  or MN39I = "I" or  MN39X = "X")) nonmilkbased = 100.

compute both=0.
if ((MN39A = "A" or MN39G = "G")  and (MN39B = "B" or MN39C = "C" or  MN39D = "D" or  MN39F = "F" or MN39H = "H"  or MN39I = "I" or  MN39X = "X")) both = 100.

compute any=0.
if (MN39A = "A" or MN39G = "G" or MN39B = "B" or MN39C = "C" or  MN39D = "D" or  MN39F = "F" or  MN39H = "H"  or MN39I = "I" or  MN39X = "X") any = 100.


variable labels nonmilkbased "Non-milk based liquids".
variable labels milkbased "Milk-based liquids".
variable labels both "Both".
variable labels any "Any".

compute layer1 = 1.
value labels layer1 1 "Type[A] of liquids or items (not considering breastmilk) consumed in the first 3 days of life".


compute total = 1.
variable labels total "Total".
value labels total 1 " ".

compute numChildren = 1.
value labels numChildren 1 "Number of most recent live-born children to women with a live birth in the last 2 years".

variable labels welevel "Mothers education".
variable labels disability "Mother's functional difficulties (age 18-49 years)".

* For labels in French uncomment commands below.
* variable labels
    monthsSinceLastBirth "Mois depuis la dernire naissance"
   /monthsSinceLastBirthGroups "Mois depuis la dernire naissance"
   /everBreastfed "tat de l'allaitement maternel"
   /exclusivelyBreastfed "Ont t allaits exclusivement [A]"
   /milk "Lait animal"
   /water "L'eau claire"
   /sugar "L'eau claire"
   /gripe "Eau gripe"
   /fruit "Jus de fruit"
   /formula "Lait maternis "
   /tea "Th / Infusions / Prparations traditionnelles  base de plantes"
   /honey "Miel"
   /ors "Mdicaments prescrits / solutions ORS / solutions sucre-sel"
   /other "Autres"
   /none "On n'a rien donn  boire"
   /welevel "Instruction de la mre"
   /disability "Difficults fonctionnelles de la mre (ge 18-49 ans)".
* value labels 
numChildren 1 "Nombre de derniers enfants ns vivants au cours des deux dernires annes [B]"
/monthsSinceLastBirthGroups 
  1 " 0-11 mois" 
  2 "12-23 mois"
/everBreastfed
  1 "Ayant t allait"
  2 "Jamais t allait"
  9 "Manquant"
/layer 
  1 "Pourcentage d'enfants qui dans les trois premiers jours:"
/otherLiquids 
  1 "Consomm autre que le lait maternel:".
  
* For labels in Spanish uncomment commands below.
* variable labels
    monthsSinceLastBirth "Meses desde el nacimiento"
   /monthsSinceLastBirthGroups "Meses desde el nacimiento"
   /everBreastfed "Estado de lactancia"
   /exclusivelyBreastfed "Fueron amamantados exclusivamente [A]"
   /milk "Leche de origen animal"
   /water "Agua sola"
   /sugar "Agua con azcar o glucosa"
   /gripe "Solucin medicinal anticlico"
   /fruit "Jugo de frutas"
   /formula "Frmula para bebs"
   /tea "T/Infusiones/Preparaciones tradicionales de hierbas"
   /honey "Miel"
   /ors "Medicamentos prescitos/SRO/Soluciones de azcar-sal"
   /other "Otro"
   /none "No se les dio nada para beber"
   /welevel "Educacin de la madre"
   /disability "Dificultades funcionales de la madre (age 18-49 years)".
* value labels 
numChildren 1 "Nmero de los ltimos nios/as nacidos en los 2 aos precedentes a la encuesta [B]"
/monthsSinceLastBirthGroups 
  1 " 0-11 meses" 
  2 "12-23 meses"
/everBreastfed
  1 "Alguna vez amamantado"
  2 "Nunca amamantado"
  9 "Ignorado"
/layer 
  1 "Porcentaje de nios que en los primeros tres das:"
/otherLiquids 
  1 "Consumieron algo que no fuera leche materna:".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /format missing = "na" 
  /vlabels variables = numChildren layer layer1 
           display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
        + monthsSinceLastBirthGroups [c]
        + everBreastfed [c]
        + personAtDelivery1 [c]
        + $deliveryPlace [c]
        + welevel [c]
        + disability[c]
        + ethnicity [c]
        + windex5 [c]
   by
        layer [c] >( milk[s][mean '' f5.1] + water[s][mean '' f5.1] + sugar[s][mean '' f5.1] + gripe[s][mean '' f5.1] + fruit[s][mean '' f5.1]
                             + formula[s][mean '' f5.1] + tea[s][mean '' f5.1] + honey[s][mean '' f5.1] + ors[s][mean '' f5.1] + other[s][mean '' f5.1])
        + layer1 [c]> (nonmilkbased [s][mean '' f5.1]+milkbased [s][mean '' f5.1]+both [s][mean '' f5.1]+any [s][mean '' f5.1])
        + numChildren[c][count '' f5.0]  
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Table TC.7.2: Newborn feeding"
     "Percentage of last live-born children ever breastfed by consumption of breastmilk and other items, percentage receiving a prelacteal feed, and percentage of child " 
     "never breastfed by consumption of other items in the first 3 days after birth, " + surveyname
  caption=
        "[A] Includes children consuming prescribed medications, ORS and sugar/salt solutions"
        "[B] Excludes children born in the 3 days before the survey"
        "na: not applicable" .
		

* Ctables command in French.
* ctables
  /format missing = "na" 
  /vlabels variables = numChildren layer otherLiquids 
           display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
        + monthsSinceLastBirthGroups [c]
        + everBreastfed [c]
        + personAtDelivery1 [c]
        + $deliveryPlace [c]
        + welevel [c]
        + disability[c]
        + ethnicity [c]
        + windex5 [c]
   by
        layer [c] >( exclusivelyBreastfed[s][mean '' f5.1]  
        + (otherLiquids [c] >(milk[s][mean '' f5.1] + water[s][mean '' f5.1] + sugar[s][mean '' f5.1] + gripe[s][mean '' f5.1] + fruit[s][mean '' f5.1]
                             + formula[s][mean '' f5.1] + tea[s][mean '' f5.1] + honey[s][mean '' f5.1] + ors[s][mean '' f5.1] + other[s][mean '' f5.1]))
        + none[s][mean '' f5.1]) + numChildren[c][count '' f5.0]  
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tableau TC.7.2: Alimentation du nouveau-n"
     "Pourcentage des derniers enfants ns vivants allaits par la consommation de lait maternel et d'autres produits, pourcentage d'enfants ayant reu une nourriture prlactaire, "+
	 "et pourcentage d'enfants n'ayant jamais allait par consommation d'autres articles dans les 3 premiers jours aprs la naissance,  " + surveyname
  caption=
        "[A] Comprend les enfants qui consomment des mdicaments prescrits, des SRO et des solutions de sucre et de sel"
        "[B] Exclut les enfants ns dans les 3 jours prcdant l'enqute"
        "na: n'est pas applicable" .
		
* Ctables command in Spanish.
* ctables
  /format missing = "na" 
  /vlabels variables = numChildren layer otherLiquids 
           display = none
  /table   total [c]
        + hh6 [c]
        + hh7 [c]
        + monthsSinceLastBirthGroups [c]
        + everBreastfed [c]
        + personAtDelivery1 [c]
        + $deliveryPlace [c]
        + welevel [c]
        + disability[c]
        + ethnicity [c]
        + windex5 [c]
   by
        layer [c] >( exclusivelyBreastfed[s][mean '' f5.1]  
        + (otherLiquids [c] >(milk[s][mean '' f5.1] + water[s][mean '' f5.1] + sugar[s][mean '' f5.1] + gripe[s][mean '' f5.1] + fruit[s][mean '' f5.1]
                             + formula[s][mean '' f5.1] + tea[s][mean '' f5.1] + honey[s][mean '' f5.1] + ors[s][mean '' f5.1] + other[s][mean '' f5.1]))
        + none[s][mean '' f5.1]) + numChildren[c][count '' f5.0]  
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tabla TC.7.2: Alimentacin del recin nacido"
     "Porcentaje de los ltimos nios/as nacidos en los 2 aos precedentes a la encuesta que fueron amamantados alguna vez, por consumo de leche materna y otros productos, "+
	 "porcentaje que recibi un alimento prelcteo y porcentaje de nios que nunca fueron amamantados por consumo de otros productos en los primeros 3 das despus del nacimiento,  " + surveyname
  caption=
        "[A] Incluye nios que consumen medicamentos prescritos, SRO y soluciones de agua con azcar y sal"
        "[B] No incluye nios nacidos en los 3 das anteriores a la encuesta"
        "na: no aplicable" .

new file.
