* Encoding: UTF-8.
* MICS6 TC-7.5.
 * Children appropriately breastfed includes children age 0-5 months who are exclusively breastfed (see table TC.7.2) and children age 6-23 months who are
  currently breastfed (BD3=1) and receiving any solid, semi-solid or soft foods (at least one 1 "Yes" to any food item in BD8).

***.


* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'ch.sav'.

select if (UF17 = 1).

weight by chweight.

* include definition of solidSemiSoft, exclusivelyBreastfed and predominantlyBreastfed .
include 'define/MICS6 - 07 - TC.sps' .

do if (cage >= 0 and cage <= 5).
+ compute approp0_5 = exclusivelyBreastfed.
end if.

variable labels approp0_5 "Children age 0-5 months".

do if (cage >= 6 and cage <= 23).
+ compute approp6_23 = 0.
+ if (BD3 = 1 and solidSemiSoft) approp6_23 = 100.
end if.
variable labels approp6_23 "Children age 6-23 months".

do if (cage >= 0 and cage <= 23).
+ compute appropAll = 0.
+ if (cage >= 0 and cage <= 5 and approp0_5 = 100) appropAll = 100.
+ if (cage >= 6 and cage <=23 and approp6_23 = 100) appropAll = 100.
end if.
variable labels appropAll "Children age 0-23 months".

compute total = 1.
variable labels total  "Total".
value labels total 1 " ".

* For labels in French uncomment commands below.
* variable labels
    approp0_5 "Enfants de 0-5 mois"
   /approp6_23 "Enfants de 6-23 mois"
   /appropAll "Enfants de 0-23 mois".

* For labels in Spanish uncomment commands below.
* variable labels
    approp0_5 "Nios/as de 0-5 meses"
   /approp6_23 "Nios/as de 6-23 meses"
   /appropAll "Nios/as de 0-23 meses".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + melevel [c]
        + caretakerdis[c]
        + ethnicity [c]
        + windex5 [c]
   by
           approp0_5  [s] [mean,'Percent exclusively breastfed [1]',f5.1,
                           validn 'Number of children' f5.0]
         + approp6_23 [s] [mean,'Percent currently breastfeeding and receiving solid, semi-solid or soft foods',f5.1,
                           validn 'Number of children' f5.0]
         + appropAll  [s] [mean,'Percent appropriately breastfed [2]',f5.1,
                          validn 'Number of children' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
     "Table TC.7.5: Age-appropriate breastfeeding"
     "Percentage of children age 0-23 months who were appropriately breastfed during the previous day, " + surveyname
   caption=
     "[1] MICS indicator TC.32 - Exclusive breastfeeding under 6 months"
     "[2] MICS indicator TC.37 - Age-appropriate breastfeeding"
  .

* Ctables command in French.
* ctables
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + melevel [c]
        + caretakerdis[c]
        + ethnicity [c]
        + windex5 [c]
   by
           approp0_5  [s] [mean,'Pourcentage exclusivement allaités [1]',f5.1,
                           validn 'Nombre d'enfants' f5.0]
         + approp6_23 [s] [mean,'Pourcentage actuellement allaités et recevant des aliments solides, semi-solides ou mous',f5.1,
                           validn 'Nombre d'enfants' f5.0]
         + appropAll  [s] [mean,'Pourcentage allaités de façon appropriée [2]',f5.1,
                          validn 'Nombre d'enfants' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
     "Tableau TC.7.5: Allaitement appropri  l'ge"
     "Pourcentage d'enfants de 0-23 mois qui ont t allaits de faon approprie durant la journe prcdente, " + surveyname
   caption=
     "[1] Indicateur MICS TC.32 - Allaitement exclusif des moins de 6 mois"
     "[2] Indicateur MICS TC.37 - Allaitement appropri  l'ge  "
  .

* Ctables command in Spanish.
* ctables
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + melevel [c]
        + caretakerdis[c]
        + ethnicity [c]
        + windex5 [c]
   by
           approp0_5  [s] [mean,'Porcentaje con lactancia exclusivamente [1]',f5.1,
                           validn 'Número de niños/as' f5.0]
         + approp6_23 [s] [mean,'Porcentaje con lactancia actualmente y que recibe alimentos sólidos, semisólidos o suaves',f5.1,
                           validn 'Número de niños/as' f5.0]
         + appropAll  [s] [mean,'Porcentaje adecuadamente amamantados [2]',f5.1,
                          validn 'Número de niños/as' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column
  /titles title=
     "Tabla TC.7.5: Lactancia apropiada para la edad"
     "Porcentaje de nios/as de 0-23 meses de edad con una lactancia apropiada durante el da previo,  " + surveyname
   caption=
     "[1] MICS indicador TC.32 - Lactancia exclusiva antes de los 6 meses"
     "[2] MICS indicador TC.37 - Lactancia apropiada para la edad"
  .  

new file.
