* Encoding: UTF-8.
* MICS5 TC-9.1.

 * Iodised salt is salt testing positive for any iodine content (SA1=2 or 3 or SA2=2 or 3). If a household has salt, but it was not tested (SA1=6 or SA2=6), it is omitted from the denominator of the indicator.

***.
* Call include file for the working directory and the survey name.
include "surveyname.sps".

get file = 'hh.sav'.

select if (HH46 = 1).

weight by hhweight.

compute numHouseholds  = 1.
value labels numHouseholds 1 "Number of households".
variable labels numHouseholds "".

recode SA1 (4 = 100) (else = 0) into noSalt.
variable labels noSalt "Percentage of households with no salt".

recode SA1 (1,2,3 = 100) (else = 0) into saltTest.
variable labels saltTest "Percentage of households in which salt was tested".

do if (noSalt  = 100 or saltTest  = 100).
+ recode SA1 (4 = 0)  (1, 2, 3 = copy) (else = sysmis) into testResult.
+ if (testResult = 1 and SA2 <= 3) testResult = SA2.
+ compute iodized=0.
+ if (testResult>=2) iodized=100.
+ compute numHouseholdsTestedOrNoSalt = 1.
variable labels iodized "Percentage of households with iodised salt [1]".
variable labels numHouseholdsTestedOrNoSalt "".
value labels numHouseholdsTestedOrNoSalt 1 "Number of households in which salt was tested or with no salt".
end if.

variable labels testResult "Percentage of households with salt test result".

value labels testResult
  0 "No salt"
  1 "Not iodized 0 PPM"
  2 ">0 and <15 PPM"
  3 "15+ PPM".

compute total = 1.
variable labels total "Total".
value labels total 1" ".

compute total100 = 100.
variable labels total100 "Total".
value labels total100 100" ".

* For labels in French uncomment commands below.
* variable labels
   saltTest "Pourcentage de mnages avec:"
  /testResult "Pourcentage de mnages dans lesquels le sel a t test"
  /iodized "Pourcentage de mnages avec du sel iod [1]".
* value labels
numHouseholdsTestedOrNoSalt
  1 "Nombre de mnages dans lesquels le sel a t analys ou n'ayant pas de sel" 
/numHouseholds
  1 "Nombre de mnages"
/testResult
  0 "Pas de sel"
  1 "Non iod 0 PPM"
  2 ">0 et <15 PPM"
  3 "15+ PPM".
  
* For labels in Spanish uncomment commands below.
* variable labels
   saltTest "Porcentaje de hogares con:"
  /testResult "Porcentaje de hogares donde se hizo prueba de sal"
  /iodized "Pourcentage de mnages avec du sel iod [1]".
* value labels
numHouseholdsTestedOrNoSalt
  1 "Nmero de hogares en los que se prob la sal o sin sal" 
/numHouseholds
  1 "Nmero de hogares"
/testResult
  0 "Sin sal"
  1 "No yodada 0 PPM"
  2 ">0 y <15 PPM"
  3 "15+ PPM".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = numHouseholds numHouseholdsTestedOrNoSalt
             display = none
  /table   total [c]
         + hh6[c]
         + hh7 [c]
         + windex5 [c]
   by
           saltTest [s] [mean '' f5.1]
         + numHouseholds [c] [count '' f5.0]
         + testResult [c] [rowpct.validn '' f5.1]
         + total100 [s] [mean '' f5.1]
         + iodized [s] [mean '' f5.1]
         + numHouseholdsTestedOrNoSalt [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
    "Table TC.9.1: Iodized salt consumption"
    "Percent distribution of households by consumption of iodized salt, " + surveyname
   caption =
    "[1] MICS indicator TC.48 - Iodized salt consumption".

* Ctables command in French.
* ctables
  /vlabels variables = numHouseholds numHouseholdsTestedOrNoSalt
             display = none
  /table   total [c]
         + hh6[c]
         + hh7 [c]
         + windex5 [c]
   by
           saltTest [s] [mean '' f5.1]
         + numHouseholds [c] [count '' f5.0]
         + testResult [c] [rowpct.validn '' f5.1]
         + total100 [s] [mean '' f5.1]
         + iodized [s] [mean '' f5.1]
         + numHouseholdsTestedOrNoSalt [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
    "Tableau TC.9.1: Consommation de sel iod"
    "Distribution en pourcentage de mnages par consommation de sel iod, " + surveyname
   caption =
    "[1]  Indicateur MICS TC.48 - Consommation de sel iod".

* Ctables command in Spanish.
* ctables
  /vlabels variables = numHouseholds numHouseholdsTestedOrNoSalt
             display = none
  /table   total [c]
         + hh6[c]
         + hh7 [c]
         + windex5 [c]
   by
           saltTest [s] [mean '' f5.1]
         + numHouseholds [c] [count '' f5.0]
         + testResult [c] [rowpct.validn '' f5.1]
         + total100 [s] [mean '' f5.1]
         + iodized [s] [mean '' f5.1]
         + numHouseholdsTestedOrNoSalt [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
    "Tabla TC.9.1: Consumo de sal yodada"
    "Distribucin de los hogares por consumo de sal yodada " + surveyname
   caption =
    "[1] MICS indicador TC.48 -  Consumo de sal yodada".

new file.
