* Encoding: windows-1252.
include "surveyname.sps".

get file = 'hl.sav'.

weight by hhweight.

* Select children who are of primary school age; this definition is
* country-specific and should be changed to reflect the situation in your
* country.

* include definition of primarySchoolEntryAge .
include 'define/MICS6 - 08 - LN.sps' .

variable labels schage "Age at beginning of school year".

select if (schage >= primarySchoolEntryAge and schage <= primarySchoolCompletionAge).

compute primary  = 0.
if (ED10A >= 1 and ED10A <= 2) primary =  100.

* Further adjust for children that are of primary school completion age and already completed primary school, but did not attend secondary.
* Set test for "Age at the begining of school year" equal to age in last grade of primary and test for ED4B equal to the last grade of primary.
if (ED5A = 1 and ED5B = primarySchoolGrades and ED6 = 1 and ED9 = 2) primary  = 100.

*  Not attending school are those who did not attend school or preschool in the current school year and have not completed primary school 
(ED9=2 and ED5A=1 and ED5B=last grade of primary school and ED6<>1).
compute notAttendingSchoolPreschool = 0 .
if (ED9 = 2 or ED4 = 2) notAttendingSchoolPreschool = 100 .
if (ED5A = 1 and ED5B = primarySchoolGrades and ED6 = 1 and ED9 = 2) notAttendingSchoolPreschool  = 0.

* Attending preschool are those who in the current school year have been attending preschool school (ED6A=0).
compute attendingPreschool = 0.
if (ED10A = 0) attendingPreschool = 100 .

* Out of school children are the sum attending preschol and not attending school.
compute outOfSchool = 0.
if (notAttendingSchoolPreschool = 100) outOfSchool = 100.

variable labels primary "".
variable labels HL4 "".

compute layer = 1.
value labels layer 1 "Percentage of children:".

compute numChildren = 1.

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

*  For labels in French uncomment commands below.
* variable labels schage "ge au dbut de l'anne scolaire".
* value labels layer 1 "Pourcentage d'enfants:".

*  For labels in Spanish uncomment commands below.
* variable labels schage "Edad al inicio del ao escolar".
* value labels layer 1 "Porcentaje de nios que:".

* Ctables command in English.
ctables
  /vlabels variables = hl4 primary layer notAttendingSchoolPreschool 
                       attendingPreschool outOfSchool numChildren
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by 
           hl4 [c] > (
             primary [s][mean,'Net attendance ratio (adjusted) [1]',f5.1] 
           + layer [c] > (
               attendingPreschool [s] [mean,'Attending early childhood education',f5.1]
             + outOfSchool [s] [mean,'Out of school [A]',f5.1] )
           + numChildren [s] [validn,'Number of children'] )
  /categories variables=all empty=exclude missing=exclude
  /categories variables=hl4 total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
    "Table LN.2.3: Primary school attendance and out of school children"												
     "Percentage of children of primary school age attending primary or lower secondary school (adjusted net attendance ratio), percentage attending early childhood education, and percentage out of school, " + surveyname
   caption =
    "[1] MICS indicator LN.5a - Primary school net attendance ratio (adjusted)"
    "[2] MICS indicator LN.6a - Out-of-school rate for children of primary school age"																	
    "[A] The percentage of children of primary school age out of school are those not attending earlly childhood education, primary or lower secondary education"
  .

* Ctables command in French.  
* ctables
  /vlabels variables = hl4 primary layer notAttendingSchoolPreschool 
                       attendingPreschool outOfSchool numChildren
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by 
           hl4 [c] > (
             primary [s][mean,'Taux net de Scolarisation (ajust) [1]',f5.1] 
           + layer [c] > (
               attendingPreschool [s] [mean,'Frquenter le prescolaire',f5.1]
             + outOfSchool [s] [mean,'Hors de l'cole [A]',f5.1] )
           + numChildren [s] [validn,' Nombre d'enfants'] )
  /categories variables=all empty=exclude missing=exclude
  /categories variables=hl4 total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
     "Tableau LN.2.3: Frquentation scolaire et enfants non scolariss"												
     "Pourcentage d'enfants en ge d'aller  l'cole primaire frquentant l'cole primaire ou secondaire 1er cycle " +
         "(taux net de scolarisation ajust), pourcentage d'enfants frequentant le prescolaire et pourcentage d'enfants en dehors de l'ecole, " + surveyname
   caption =
    "[1] Indicateur MICS LN.5a - Taux net de frquentation scolaire primaire (ajust)"
    "[2] Indicateur MICS LN.6a - Taux d'abandon scolaire pour les enfants en ge de frquenter"																	
    "[A]  The percentage of children of primary school age out of school are those not attending earlly childhood education, primary or lower secondary education"
  .


* Ctables command in Spanish.  
* ctables
  /vlabels variables = hl4 primary layer notAttendingSchoolPreschool 
                       attendingPreschool outOfSchool numChildren
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by 
           hl4 [c] > (
             primary [s][mean,'Tasa neta de asistencia (ajustada) [1]',f5.1] 
           + layer [c] > (
              attendingPreschool [s] [mean,'Asisten a educacin de la primera infancia',f5.1]
             + outOfSchool [s] [mean,'Fuera de la escuela [A]',f5.1] )
           + numChildren [s] [validn,'Nmero de nios'] )
  /categories variables=all empty=exclude missing=exclude
  /categories variables=hl4 total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
     "Tabla LN.2.3: Asistencia a la escuela primaria y nios no asistiendo a la escuela"												
     "Porcentaje de nios en edad de escuela primaria que asisten a la escuela primaria o secundaria baja " +
             "(tasa neta de asistencia ajustada), porcentaje que asiste a educacin de la primera infancia y porcentaje que no asiste a la escuela, " + surveyname
   caption =
    "[1] MICS indicador LN.5a - Tasa neta de asistencia a la escuela primaria (ajustada)"
    "[2] MICS indicator LN.6a - Tasa de desercin escolar para nios en edad de asistir a la escuela primaria"																	
    "[A]  The percentage of children of primary school age out of school are those not attending earlly childhood education, primary or lower secondary education"
  .  

new file.
