* Encoding: windows-1252.
include "surveyname.sps".

get file = 'hl.sav'.

weight by hhweight.

* Select children who are of primary school age; this definition is
* country-specific and should be changed to reflect the situation in your
* country.

* include definition of primarySchoolEntryAge .
include 'define/MICS6 - 08 - LN.sps' .

select if (schage >= LowSecSchoolEntryAge and schage <= LowSecSchoolCompletionAge).

variable labels schage "Age at beginning of school year".

compute secondary  = 0.
if (ED10A >= 2 and ED10A <= 3) secondary =  100.

* Set test for "Age at the begining of school year" equal to age in last grade of secondary and test for ED4B equal to the last grade of secondary.
if (ED5A = 2 and ED5B = LowSecSchoolGrades and ED6 = 1 and ED9 = 2) secondary  = 100.

compute primary  = 0.
if (ED10A = 1) primary =  100.

*The percentage of children out of school are those who are not attending lower secondary school or higher, those who are not attending primary school, 
*and those who have not already completed lower secondary school: ED9=2 and (ED5A=2 and ED5B=last grade of lower secondary school and ED6<>1)).
compute outOfSchool = 0 .
if (ED9 = 2 or ED4 = 2) outOfSchool = 100.
if (ED5A = 2 and ED5B = LowSecSchoolGrades and ED6 = 1 and ED9 = 2) outOfSchool  = 0.

variable labels primary "".
variable labels secondary "".
variable labels outOfSchool "".
variable labels HL4 "".

compute layer = 1.
value labels layer 1 "Percentage of children:".

add value labels melevel 7 "No information [B]".
add value labels caretakerdis 7 "No information [B]".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

*  For labels in French uncomment commands below.
* variable labels schage "ge au dbut de l'anne scolaire".
* add value labels melevel 7 "Aucune information [B]".
* add value labels caretakerdis 7 "Aucune information [B]".

*  For labels in Spanish uncomment commands below.
* variable labels schage "Edad al inicio del ao escolar".
* add value labels melevel 7 "No information [B]".
* add value labels caretakerdis 7 "No information [B]".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = hl4 secondary primary outOfSchool layer
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by
           hl4 [c] > (
             secondary [s] [mean,'Net attendance ratio (adjusted) [1]',f5.1]
           + layer [c] > (primary   [s] [mean,'Attending primary school',f5.1]
           + outOfSchool [s] [mean,'Out of school [2] [A]',f5.1])
           + secondary [s] [validn,'Number of children',f5.0] )
  /categories variables=all empty=exclude missing=exclude
  /categories variables=hl4 total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
    "Table LN.2.4: Lower secondary school attendance and out of school adolescents"												
    "Percentage of children of secondary school age attending lower secondary school or higher (adjusted net attendance ratio), percentage attending primary school, and percentage out of school, " + surveyname
   caption =
    "[1] MICS indicator LN.5b - Lower secondary school net attendance ratio (adjusted)"
    "[2] MICS indicator LN.6b - Out-of-school rate for adolescents of lower secondary school age"													
    "[A] The percentage of children of lower secondary school age out of school are those who are not attending primary, secondary or higher education"
    "[B] Children age 15 or higher identified as emancipated".

* Ctables command in French.  
* ctables
  /vlabels variables = hl4 secondary primary outOfSchool layer
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by
           hl4 [c] > (
             secondary [s] [mean,' Taux net de Scolarisation (ajust) [1]',f5.1]
           + layer [c] > (primary   [s] [mean,'Frquenter l'cole primaire',f5.1]
           + outOfSchool [s] [mean,'Hors de l'cole [A]',f5.1])
           + secondary [s] [validn,'Nombre d'enfants',f5.0] )
  /categories variables=all empty=exclude missing=exclude
  /categories variables=hl4 total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
    "Tableau LN.2.4: Frquentation scolaire dans le secondaire 1er cycle et adolescents non scolariss"												
    "Pourcentage d'enfants en ge d'aller  l'cole secondaire frquentant l'cole secondaire  1er cycle ou suprieure " +
    "(taux net de scolarisation ajust), pourcentage d'lves frquentant l'cole primaire et pourcentage d'enfants en dehors de l'ecole, " + surveyname																												  
   caption =
    "[1] Indicateur MICS LN.5b - Taux net de scolarisation dans l'enseignement secondaire infrieur (ajust)"
    "[2] Indicateur MICS LN.6b - Taux d'abandon extrascolaire des adolescents en ge de frquenter l'cole secondaire"													
    "[A] Le pourcentage d'enfants non scolariss dans le premier cycle du secondaire concerne ceux qui ne frquentent ni l'enseignement primaire, ni le secondaire ou suprieur"
    "[B] Enfants gs de 15 ans ou plus au moment de l'interview".

* Ctables command in Spanish.  
* ctables
  /vlabels variables = hl4 secondary primary outOfSchool layer
           display = none
  /table   total [c] 
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + melevel [c]
         + caretakerdis [c]
         + ethnicity [c]         
         + windex5 [c]
   by
           hl4 [c] > (
             secondary [s] [mean,'Tasa neta de asistencia (ajustada) [1]',f5.1]
           + layer [c] > (primary   [s] [mean,'Que asisten a la escuela primaria',f5.1]
           + outOfSchool [s] [mean,'Fuera de la escuela [A]',f5.1])
           + secondary [s] [validn,'Nmero de nios',f5.0] )
  /categories variables=all empty=exclude missing=exclude
  /categories variables=hl4 total=yes position = after label = "Total"
  /slabels position=column
  /titles title=
    "Tabla LN.2.4: Asistencia a la escuela secundaria baja y adolescentes que no asisten a la escuela"												
    "Porcentaje de nios en edad de asistir a la escuela secundaria que asisten a la escuela secundaria baja o superior " +
    "(tasa neta de asistencia ajustada), porcentaje que asistencia a la escuela primaria, y porcentaje que no asisten a la escuela, " + surveyname
   caption =
    "[1] MICS indicador LN.5b -  Tasa neta de asistencia a la escuela secundaria baja (ajustada)"
    "[2] MICS indicador LN.6b - Tasa de desercin escolar para adolescentes en edad de asistir a la escuela secundaria baja"													
    "[A] El porcentaje de nios en edad de escuela secundaria baja fuera de la escuela son aquellos que no asisten a la escuela primaria, secundaria o educacin superior"
    "[B] Jvenes de 15 aos o ms en el momento de la entrevista".

new file.
