* Encoding: windows-1252.

include "surveyname.sps".

get file = 'fs.sav'.

include "define/MICS6 - 08 - LN.sps".

weight by fsweight.

select if (CB3 >=7 and CB3<=14).

compute attendingSchool = 0.
if (CB7 = 1) attendingSchool = 100.
variable labels attendingSchool "Percentage of children attending school [A]".

compute NumChildren = 1.
variable labels NumChildren "Number of children age 7-14 years".

do if (attendingSchool = 100).

*Percentage of children for whom an adult household member in the last year received a report card for the child: PR10=1.
compute receivedCard = 0.
if (PR10=1) receivedCard = 100.

 * Involvement by adult in school management in last year
- School has a governing body open to parents: PR7=1
- Attended meeting called by governing body: PR8=1
- A meeting discussed key education/financial issues: PR9 [A]=1 or PR9 [B]=1.

compute govBody = 0.
if (PR7=1) govBody = 100.

compute govBodyMeeting = 0.
if (PR8=1) govBodyMeeting = 100.

compute EdMeeting = 0.
if (PR9A=1 or PR9B = 1) EdMeeting = 100.

 * Involvement by adult in school activities in last year
- Attended school celebration or a sport event: PR11 [A]=1
- Met with teachers to discuss child's progress: PR11 [B]=1.

compute event = 0.
if (PR11A = 1) event = 100.

compute progress = 0.
if (PR11B = 1) progress = 100.

compute numAttending = 1.

end if.

compute layer1 = 0.
compute layer2 = 0.

variable labels layer1 "".
value labels layer1 0 "Involvement by adult in school management in last year".

variable labels layer2 "".
value labels layer2 0 "Involvement by adult in school activities in last year	".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

variable labels receivedCard "Percentage of children for whom an adult household member in the last year received a report card for the child [1]".
variable labels numAttending "Number of children age 7-14 years attending school".
variable labels govBody "School has a governing body open to parents [2]".
variable labels govBodyMeeting "Attended meeting called by governing body [3]".
variable labels EdMeeting "A meeting discussed key education/ financial issues [4]".
variable labels event "Attended school celebration or a sport event".
variable labels progress "Met with teachers to discuss child's progress [5]".			

recode CB8A (0=0)(1=1)(2=2)(3,4, 5 = 3) (8,9 = 9)(else = 10) into school.
variable labels school "School attendance [A]".
value labels school
0 "Early childhood education"
1 "Primary"
2 "Lower secondary"
3 "Upper secondary"
9 "DK/Missing"
10 "Out-of-school".

* Children in Public are: ED11=1; Non-public: ED11=2-6. Children for whom the respondent did not know the management sector, 
ED11=8, if present in data, can be shown separately or also suppressed from disaggregate by adding this condition to note B (second sentence): 
"Children out of school, attending ECE or for whom the sector was not known by respondent are not shown.".
do if (ED10A > 0).
+ recode ED11 (11 = 1) (2 thru 6 = 2) (else = 9) into schoolManagment.
end if.
variable labels schoolManagment "School management [B]".
1 "Public"
2 "Non-public"
9 "DK/Missing".


*  For labels in French uncomment commands below.
*variable labels 
       attendingSchool "Pourcentage d'enfants frquentant l'cole [A]"
	  /NumChildren "Nombre d'enfants gs de 7-14 ans"
	  /receivedCard "Pourcentage d'enfants pour lesquels un membre adulte du mnage a reu un bulletin scolaire pour l'enfant [1]"
      /numAttending "Nombre d'enfants gs de 7-14 ans frquentant l'cole"
      /govBody "L'cole a un organe directeur ouvert aux parents [2]"
      /govBodyMeeting "Participation aux runions  convoque par un organe directeur [3]"
      /EdMeeting "Une runion a abord des questions ducatives et financieres cls [4]"
      /event "Participation aux Clbration scolaire ou vnement sportif "
      /progress "Rencontr des enseignants pour discuter des progres de l'enfant [5]".  
* value labels 
      layer1 0 "Implication d'un adulte dans la gestion scolaire l'anne derniere "	  
	 /layer2 0 "Implication d'un adulte dans des activits scolaires l'anne derniere ".
* variable labels school "Frquentation scolaire [A]".
* value labels school
      0 "Pr-primaire ou aucun"
      1 "Primaire"
      2 "Secondaire 1er Cycle"
      3 "Secondaire 2eme Cycle"
      9 "NSP/Manquant"
      10 "En dehors de l'Ecole'".
*variable labels schoolManagment "School management [B]".
*1 "Public"
*2 "Non-public"
*9 "DK/Missing".

*  For labels in Spanish uncomment commands below.
*variable labels 
       attendingSchool "Porcentaje de nios que asisten a la escuela [A]"
	  /NumChildren "Nmero de nios de 7-14 aos"
	  /receivedCard "Porcentaje de nios para quienes un miembro adulto del hogar en el ltimo ao recibi una boleta de calificaciones del nio [1]"
      /numAttending "Nmero de nios de 7 a 14 aos que asisten a la escuela"
      /govBody "La escuela tiene un cuerpo de gobierno abierto a los padres [2]"
      /govBodyMeeting "Asisti a una reunin convocada por el rgano de gobierno [3]"
      /EdMeeting "Se discutieron en una reunin asuntos clave de educacin/  financieros [4]"
      /event "Asisti a una celebracin de la escuela o a  un evento deportivo"
      /progress "Se reuni con los maestros para hablar sobre el progreso del nio/a [5]".  
* value labels 
      layer1 0 "Participacin de un adulto en la gestin escolar en el ltimo ao"	  
	 /layer2 0 "Participacin de un adulto en las actividades escolares en el ao pasado".
* variable labels school "Asistencia a la escuela [A]".
* value labels school
      0 "Pre-primaria o ninguna"
      1 "Primaria"
      2 "Secundaria baja"
      3 "Secundaria alta"
      9 "NS/Ignorado"
      10 "'Fuera de la escuela".
*variable labels schoolManagment "School management [B]".
*1 "Public"
*2 "Non-public"
*9 "DK/Missing".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /format missing = "na" 
  /vlabels variables = layer1 layer2
           display = none
  /table   total [c] 
        + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + school [c]
         + melevel [c]
         + schoolManagment [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
           attendingSchool [s] [mean '' f5.1] 
           + NumChildren [s] [validn '' f5.0] 
           + receivedCard [s] [mean '' f5.1] 
           + layer1 [c] > (govBody [s] [mean '' f5.1] + govBodyMeeting [s] [mean '' f5.1] + EdMeeting [s] [mean '' f5.1]) 
           + layer2 [c] > (event [s] [mean '' f5.1] + progress [s] [mean '' f5.1]) 
           + numAttending [s] [validn '' f5.0] 
  /categories var=all empty=exclude missing=exclude
  /slabels position=column visible=no
  /titles title=
    "Table LN.3.1: Support for child learning at school"								
     "Percentage of children attending school and, among those, percentage of children for whom an adult member of the household received a report card for the child, "
      "and involvement of adults in school management and school activities in the last year, " + surveyname
   caption = 
   "[1] MICS indicator LN.12 - Availability of information on children's school performance"									
   "[2] MICS indicator LN.13 - Opportunity to participate in School Management"									
   "[3] MICS indicator LN.14: Participation in school management"								
   "[4] MICS indicator LN.15 - Effective participation in school management"							
   "[5] MICS indicator LN.16 - Discussion with teachers regarding childrens progress"							
   "[A] Attendance to school here is not directly comparable to net attendance ratios reported in preceding tables, " +
  "which utilise information on all children in the sample. This and subsequent tables present results of the Parental Participation and Foundational Learning Skills " +
  "modules administered to mothers of a randomly selected subsample of children age 7-14 years."		
   "[B] School management sector was collected for children attending primary education or higher. Children out of school or attending ECE are not shown."						
    "na: not applicable".								

* Ctables command in French.  
* ctables
  /format missing = "na" 
  /vlabels variables = layer1 layer2
           display = none
  /table   total [c] 
        + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + schage [c]
         + school [c]
         + melevel [c]
         + schoolManagment [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
           attendingSchool [s] [mean '' f5.1] 
           + NumChildren [s] [validn '' f5.0] 
           + receivedCard [s] [mean '' f5.1] 
           + layer1 [c] > (govBody [s] [mean '' f5.1] + govBodyMeeting [s] [mean '' f5.1] + EdMeeting [s] [mean '' f5.1]) 
           + layer2 [c] > (event [s] [mean '' f5.1] + progress [s] [mean '' f5.1]) 
           + numAttending [s] [validn '' f5.0] 
  /categories var=all empty=exclude missing=exclude
  /slabels position = column visible=no  
  /titles title=
    "Tableau LN.3.1: Soutien  l'apprentissage des enfants  l'cole"								
     "Pourcentage d'enfants frquentant l'cole et, parmi ceux-ci, le pourcentage d'enfants pour lesquels un membre adulte du mnage a reu un bulletin scolaire pour l'enfant, "
      "et l'implication des adultes dans la gestion scolaire et les activits scolaires au cours de la dernire anne, " + surveyname
   caption = 
   "[1] Indicateur MICS LN.12 - Disponibilit d'informations sur la performance scolaire des enfants"									
   "[2] Indicateur MICS LN.13 - Opportunite de participer a la gestion de l'cole"									
   "[3] Indicateur MICS LN.14: Participation a la gestion de l'cole"								
   "[4] Indicateur MICS LN.15 - Participation effective a la gestion de l'cole"							
   "[5] Indicateur MICS LN.16 - Discussion avec les enseignants sur les progres des enfants"							
   "[A] La frquentation de l'cole n'est pas directement comparable aux taux net de frquentation  indiqus dans les tableaux prcdents, " +
  "qui utilisent l'information sur tous les enfants de l'chantillon. Ce tableau et les suivants prsentent les rsultats  " +
  "des modules sur la participation parentale et les comptences d'apprentissage de base administrs aux meres d'un sous-chantillon d'enfants gs de 7 a 14 ans choisis au hasard."		
   "[B] School management sector was collected for children attending primary education or higher. Children out of school or attending ECE are not shown."								
  "na: n'est pas applicable".

* Ctables command in Spanish (currently active, comment it out if using different language).
* ctables
  /format missing = "na" 
  /vlabels variables = layer1 layer2
           display = none
  /table   total [c] 
        + hl4 [c]
         + hh6 [c]
         + hh7 [c]
          + schage [c]
         + school [c]
         + melevel [c]
         + schoolManagment [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
           attendingSchool [s] [mean '' f5.1] 
           + NumChildren [s] [validn '' f5.0] 
           + receivedCard [s] [mean '' f5.1] 
           + layer1 [c] > (govBody [s] [mean '' f5.1] + govBodyMeeting [s] [mean '' f5.1] + EdMeeting [s] [mean '' f5.1]) 
           + layer2 [c] > (event [s] [mean '' f5.1] + progress [s] [mean '' f5.1]) 
           + numAttending [s] [validn '' f5.0] 
  /categories var=all empty=exclude missing=exclude
  /slabels position=column visible=no
  /titles title=
    "Tabla LN.3.1: Apoyo al aprendizaje de nios en la escuela"								
     "Porcentaje de nios que asisten a la escuela y, entre ellos, porcentaje de nios por los que un miembro adulto del hogar recibi una boleta de calificaciones del nio y " +
     "participacin de adultos en la gestin escolar y actividades escolares en el ltimo ao, " + surveyname
   caption = 
   "[1] MICS indicador LN.12 -Disponibilidad de informacin sobre el rendimiento escolar de los nios"									
   "[2] MICS indicador LN.13 - Oportunidad para participar en la gestin escolar"									
   "[3] MICS indicador LN.14: Participacin en la gestin escolar"								
   "[4] MICS indicador LN.15 - Participacin efectiva en la gestin escolar"							
   "[5] MICS indicador LN.16 - Discusin con los maestros sobre el progreso de los nios"							
   "[A] La asistencia a la escuela aqu no es directamente comparable a las tasas de asistencia neta reportadas en las tablas anteriores, " +
   "que utilizan informacin sobre todos los nios/as de la muestra. Esta y las tablas siguientes presentan los resultados de los mdulos de Participacin de los padres y " +
   "Competencias fundacionales para el aprendizaje que se administran a las madres de una submuestra de nios de 7 a 14 aos seleccionados al azar."	
    "[B] School management sector was collected for children attending primary education or higher. Children out of school or attending ECE are not shown."						
  "na: no aplicable".						

new file.
