* Encoding: windows-1252.
***.

include "surveyname.sps".

get file = 'ch.sav'.

weight by chweight.

select if (UF17 = 1) .

* children whose birth certificate was seen by the interviewer (BR1=1).
compute certificateSeen = 0.
if (BR1 = 1) certificateSeen = 100.
variable labels certificateSeen "Seen".

* children reported to have a birth certificate that was not seen by the interviewer (BR1=2).
compute certificateNotSeen = 0.
if (BR1 = 2) certificateNotSeen = 100.
variable labels certificateNotSeen "Not seen".

* children who do not have a birth certificate but are reported to have been registered with civil authorities (BR2=1). 
compute noCertificate = 0.
if (BR1 <> 1 and BR1 <> 2 and BR2 = 1) noCertificate = 100.
variable labels noCertificate "No birth certificate".

compute birthRegistrated = 0.
if (BR1 = 1 or BR1 = 2 or BR2 = 1) birthRegistrated = 100.
variable labels birthRegistrated "Total registered [1]".

* The denominator for children whose mothers/caretakers know how to register birth (BR3=1) 
* includes children who are not registered (BR1=3 and BR2=2) as well as children whose registration status is unknown.
do if (birthRegistrated = 0).
+ compute knowHow = 0.
+ if (BR3 = 1) knowHow = 100.
end if.
variable labels knowHow "Percent of children whose mothers/ caretakers know how to register births".

if (birthRegistrated = 0) numWithout = 1.
variable labels numWithout "".
value labels numWithout 1 "Number of children under age 5 without birth registration".

compute layerRegistrated = 1.
variable labels layerRegistrated "".
value labels layerRegistrated 1 "Children under age 5 whose birth is registered with civil authorities".

compute layerCertificate = 0.
variable labels layerCertificate "".
value labels layerCertificate 0 "Has birth certificate".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

compute numChildren = 1.
variable labels numChildren "".
value labels numChildren 1 "Number of children under age 5".

variable labels cdisability "Functional difficulty (age 2-4 years) [A]".

*  For labels in French uncomment commands below.
* variable labels 
     certificateSeen "Vu"
	/certificateNotSeen "Pas vu"
	/noCertificate "Pas d'acte de naissance"
	/birthRegistrated " Total enregistr [1]"
	/knowHow "Pourcentage d'enfants dont les mres / gardiennes savent enregistrer les naissances"
	/cdisability "Difficults fonctionnelles (age 2-4 ans) [A]".
*value labels 
     numWithout 1 "Nombre d'enfants de moins de 5 ans sans acte de naissance"
	/layerRegistrated 1 "Enfants de moins de 5 ans dont les naissances sont enregistres auprs des autorits civiles"
	/layerCertificate 0 "Avoir un acte de naissance"
	/numChildren 1 "Nombre d'enfants de moins de 5 ans".
	
*  For labels in Spanish uncomment commands below.
* variable labels 
     certificateSeen "Visto"
	/certificateNotSeen "No visto"
	/noCertificate "No hay certificado de nacimiento"
	/birthRegistrated " Total registrados [1]"
	/knowHow "Porcentaje de nios/as cuyas madres/ cuidadoras saben cmo registrar el nacimiento"
	/cdisability "Dificultades funcionales (edad 2-4 aos) [A]".
*value labels 
     numWithout 1 "Nmero de nios/as sin  registro de nacimiento"
	/layerRegistrated 1 "Nios/as menores de 5 aos cuyo nacimiento est registrado con las autoridades civiles"
	/layerCertificate 0 "Tiene certificado de nacimiento"
	/numChildren 1 Nmero de nios/as  menores de 5 aos".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = layerRegistrated layerCertificate numWithout numChildren
           display = none
  /table  total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + cage_11 [c]
         + melevel [c] 
         + cdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
          layerRegistrated [c] > (
            layerCertificate[c] > (
              certificateSeen [s] [mean '' f5.1]
            + certificateNotSeen [s] [mean '' f5.1] )
          + noCertificate [s] [mean '' f5.1]
          + birthRegistrated [s] [mean '' f5.1] )
        + numChildren [c] [count '' f5.0]
         + knowHow[s] [mean '' f5.1]
         + numWithout [c] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible=no
  /titles title=
     "Table PR.1.1: Birth registration"
     "Percentage of children under age 5 by whether birth is registered and percentage of children not registered whose mothers/caretakers know how to register births, " + surveyname
   caption=
     "[1] MICS indicator PR.1 - Birth registration; SDG indicator 16.9.1"
     "[A] Children age 0-1 years are excluded, as functional difficulties are only collected for age 2-4 years."
  .	

* Ctables command in French.  
* ctables
  /vlabels variables = layerRegistrated layerCertificate numWithout numChildren
           display = none
  /table  total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + cage_11 [c]
         + melevel [c] 
         + cdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
          layerRegistrated [c] > (
            layerCertificate[c] > (
              certificateSeen [s] [mean '' f5.1]
            + certificateNotSeen [s] [mean '' f5.1] )
          + noCertificate [s] [mean '' f5.1]
          + birthRegistrated [s] [mean '' f5.1] )
        + numChildren [c] [count '' f5.0]
         + knowHow[s] [mean '' f5.1]
         + numWithout [c] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible=no
  /titles title=
     "Tableau PR.1.1: Enregistrement des naissances"
     "Pourcentage d'enfants de moins de 5 ans selon que la naissance est enregistre et le pourcentage d'enfants non enregistrs dont les mres / gardiennes savent enregistrer les naissances" + surveyname
   caption=
     "[1] Indicateur MICS PR.1 - Enregistrement des naissances;  Indicateur ODD 16.9.1"
     "[A] Les enfants gs de 0  1 an sont exclus, car les difficults fonctionnelles ne sont recueillies que pour les enfants de 2  4 ans."

* Ctables command in Spanish.  
* ctables
  /vlabels variables = layerRegistrated layerCertificate numWithout numChildren
           display = none
  /table  total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + cage_11 [c]
         + melevel [c] 
         + cdisability [c]
         + mdisability [c]
         + ethnicity [c]
         + windex5 [c]
   by
          layerRegistrated [c] > (
            layerCertificate[c] > (
              certificateSeen [s] [mean '' f5.1]
            + certificateNotSeen [s] [mean '' f5.1] )
          + noCertificate [s] [mean '' f5.1]
          + birthRegistrated [s] [mean '' f5.1] )
        + numChildren [c] [count '' f5.0]
         + knowHow[s] [mean '' f5.1]
         + numWithout [c] [count '' f5.0] 
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible=no
  /titles title=
     "Tabla PR.1.1: Registro de nacimiento"
     "Porcentaje de nios/as menores de 5 aos segn si el nacimiento fue registrado y porcentaje de nios/as no registrados cuyas madres/cuidadoras saben cmo registrar el nacimiento," + surveyname
   caption=
     "[1] Indicador MICS PR.1 - Registro de nacimiento; Indicador ODS 16.9.1"
     "[A] Se excluyen los nios/as de 0-1 aos de edad debido a que la informacin sobre dificultades funcionales solo se colecta para la edad de 2-4 aos."

new file .
