* Encoding: windows-1252.

include "surveyname.sps".

get file = 'fs.sav'.

include "CommonVarsFS.sps".

select if (FS17 = 1).

weight by fsweight.

* definitions of econcomic activity variables  (ea1more, ea14less, ea14more, ea43less, ea43more) .
include 'define\MICS6 - 09 - PR.sps' .

variable labels
   eaLess "Below the age specific threshold"
  /eaMore "At or above the age specific threshold"
  /hhcLess "Below the age specific threshold"
  /hhcMore "At or above the age specific threshold"
  /hazardConditions "Children working under hazardous conditions"
  /childLabor "Total child labour [1]" .

compute layerEA = 1 .
compute layerHHC = 1 .
compute numChildren = 1 .

value labels
   layerEA   1 "Children involved in economic activities for a total number of hours during last week:"
  /layerHHC  1 "Children involved in household chores for a total number of hours during last week:"
  /numChildren 1 "Number of children age 5-17 years"
  .

recode CB3 (5 thru 11 = 1) (12 thru 14 = 2) (15 thru 17 = 3) into ageGroup .
variable labels ageGroup "Age" .
value labels ageGroup
1 "5-11"
2 "12-14"  
3 "15-17".
formats ageGroup (f1.0).

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

add value labels melevel 7 'No information [A]'.

*  For labels in French uncomment commands below.
* variable labels 
   eaLess "Au-dessous du seuil spcifique  l'ge"
  /eaMore "Au niveau ou au-dessus du seuil spcifique  l'ge"
  /hhcLess "Au-dessous du seuil spcifique  l'ge"
  /hhcMore "Au niveau ou au-dessus du seuil spcifique  l'ge"
  /hazardConditions "Enfants travaillant dans des conditions dangereuses"
  /childLabor "Total travail des enfants [1]" .
* value labels
   layerEA   1 "Enfants impliqus dans des activits conomiques pendant un nombre total d'heures au cours de la semaine dernire:"
  /layerHHC  1 "Enfants impliqus dans les tches mnagres pendant un nombre total d'heures au cours de la semaine dernire:"
  /numChildren 1 "Nombre d'enfants gs de 5-17 ans".

*  For labels in Spanish uncomment commands below.
* variable labels 
   eaLess "Debajo del umbral para la edad especfica"
  /eaMore "En o arriba del umbral para la edad especfica"
  /hhcLess "Debajo del umbral para la edad especfica"
  /hhcMore "En o arriba del umbral para la edad especfica"
  /hazardConditions "Nios/as trabajando en condiciones peligrosas"
  /childLabor "Total trabajo infantil [1]" .
* value labels
   layerEA   1 "Nios/as participando en actividades econmicas por un nmero total de horas durante la ltima semana:"
  /layerHHC  1 "Nios/as participando en tareas domsticas por un nmero total de horas durante la ltima semana:"
  /numChildren 1 "Nmero de nios/as de 5-17 aos".
  

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = numChildren layerEA layerHHC
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + schoolAttendance [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
           layerEA [c] > (
             ealess[s] [mean '' f5.1]
           + eaMore[s] [mean '' f5.1] )
         + layerHHC [c] > (
             hhcLess[s] [mean '' f5.1]
           + hhcMore[s] [mean '' f5.1] )
         + hazardConditions [s] [mean '' f5.1]
         + childLabor [s] [mean '' f5.1]
         + numChildren [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Table PR.3.3: Child labour"
      "Percentage of children age 5-17 years by involvement in economic activities or household chores during the last week, percentage " +
     "working under hazardous conditions during the last week, and percentage engaged in child labour during the last week, " + surveyname
   caption=
     "[1] MICS indicator PR.3 - Child labour; SDG indicator 8.7.1"
     "[A] Children age 15 or higher identified as emancipated"
  .			

* Ctables command in French.  
* ctables
  /vlabels variables = numChildren layerEA layerHHC
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + schoolAttendance [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
           layerEA [c] > (
             ealess[s] [mean '' f5.1]
           + eaMore[s] [mean '' f5.1] )
         + layerHHC [c] > (
             hhcLess[s] [mean '' f5.1]
           + hhcMore[s] [mean '' f5.1] )
         + hazardConditions [s] [mean '' f5.1]
         + childLabor [s] [mean '' f5.1]
         + numChildren [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tableau PR.3.3: Travail des enfants"
      "Pourcentage d'enfants gs de 5  17 ans ayant particip  des activits conomiques ou  des tches mnagres au cours de la dernire semaine, " +
     "pourcentage travaillant dans des conditions dangereuses au cours de la dernire semaine et pourcentage de travail des enfants au cours de la dernire semaine, " + surveyname
   caption=
     "[1] Indicateur MICS PR.3 - Travail des enfants; Indicateur ODD 8.7.1"
     "[A] Un enfant de 15 ans ou plus identifi comme mancip".
 
* Ctables command in Spanish.  
* ctables
  /vlabels variables = numChildren layerEA layerHHC
           display = none
  /table   total [c]
         + hl4 [c]
         + hh6 [c]
         + hh7 [c]
         + schoolAttendance [c]
         + melevel [c]
         + fsdisability [c]
         + caretakerdis [c]
         + ethnicity [c]
         + windex5 [c]
   by
           layerEA [c] > (
             ealess[s] [mean '' f5.1]
           + eaMore[s] [mean '' f5.1] )
         + layerHHC [c] > (
             hhcLess[s] [mean '' f5.1]
           + hhcMore[s] [mean '' f5.1] )
         + hazardConditions [s] [mean '' f5.1]
         + childLabor [s] [mean '' f5.1]
         + numChildren [c] [count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tabla PR.3.3: Trabajo infantil"
      "Porcentaje de nios/as de 5 a 17 aos por su participacin en actividades econmicos o tareas domsticas durante la ltima semana, " +
     "porcentaje trabajando bajo condiciones peligrosas durante la ltima semana, y porcentaje dedicado a trabajo infantil durante la ltima semana, " + surveyname
   caption=
     "[1] Indicador MICS PR.3 - Trabajo infantil; Indicador ODS 8.7.1"
     "[A] Nios/as de 15 o ms aos identificados como emancipados/as".

new file.
