﻿* Encoding: windows-1252.
 * The percentage of women age 15-49 years who in the last 12 months have felt discriminated against or harassed is tabulated by frequency of basis for discrimination or 
    harassment using question VT22A through VT22X. A 'yes' to any of these questions is included in the numerator of MICS indicator 15.4.
***.

include "surveyname.sps".

get file="wm.sav".

include "CommonVarsWM.sps".

select if (WM17 = 1).

weight by wmweight.

compute VT22ethnic = 0.
if (VT22A = 1) VT22ethnic = 100.
variable labels VT22ethnic "Ethnic or immigration origin".

compute VT22sex = 0.
if (VT22B = 1) VT22sex = 100.
variable labels VT22sex "Sex".

compute VT22sexual = 0.
if (VT22C = 1) VT22sexual = 100.
variable labels VT22sexual "Sexual orientation".

compute VT22age = 0.
if (VT22D = 1) VT22age = 100.
variable labels VT22age "Age".

compute VT22religion = 0.
if (VT22E = 1) VT22religion = 100.
variable labels VT22religion "Religion or belief".

compute VT22disability = 0.
if (VT22F = 1) VT22disability = 100.
variable labels VT22disability "Disability".

compute VT22other = 0.
if (VT22X = 1) VT22other = 100.
variable labels VT22other "Other reason".

compute any = 0.
if (VT22A = 1 or VT22B = 1 or VT22C = 1 or VT22D = 1 or VT22E = 1 or VT22F = 1 or VT22X = 1) any = 100.
variable labels any "Any reason [1]".

compute nodiscrimination = 0.
if (any = 0) nodiscrimination = 100.
variable labels nodiscrimination "Percentage of women age 15-49 who have not felt discriminated against or harassed in the last 12 months".

compute layer = 1.
value labels layer 1 "Percentage of women age 15-49 years who in the last 12 months have felt discriminated against or harassed on the basis of: ".

compute numWomen = 1.
value labels numWomen 1 "Number of women age 15-49 years".

compute total = 1.
variable labels total "Total".
value labels total 1 " ".

*  For labels in French uncomment commands below.
* variable labels
     VT22ethnic "Origine ethnique ou d'immigration"
	/VT22sex "Genre"
	/VT22sexual "Orientation sexuelle"
	/VT22age "Âge"
	/VT22religion "Religion ou croyance"
	/VT22disability "Invalidité"
	/VT22other "Autre raison"
	/any "Toute raison [1]"
	/nodiscrimination "Pourcentage de femmes âgées de 15 à 49 ans qui ne se sont pas senties discriminées ou harcelées au cours des 12 derniers mois".
* value labels 
     layer 1 "Pourcentage de femmes âgées de 15 à 49 ans qui, au cours des 12 derniers mois, se sont senties discriminées ou harcelées sur la base de:"
	/numWomen 1 "Nombre de femmes âgées de 15 à 49 ans".

	
*  For labels in Spanish uncomment commands below.
* variable labels
     VT22ethnic "Origen étnico o inmigración"
	/VT22sex "Género"
	/VT22sexual "Orientación  sexual"
	/VT22age "Edad"
	/VT22religion "Religión o creencias"
	/VT22disability "Discapacidad"
	/VT22other "Otra razón"
	/any "Cualquier razón [1]"
	/nodiscrimination "Porcentaje de mujeres de 15-49 años de edad que no se han sentido discriminadas ni acosadas en los últimos 12 meses".
* value labels 
     layer 1 "Porcentaje de mujeres de 15-49 años de edad que en los últimos 12 meses se han sentido discriminados o acosados sobre la base de:"
	/numWomen 1 "Número de mujeres de 15-49 años de edad".	

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables = layer numWomen
           display = none
  /table  total [c]
         + HH6 [c]
         + HH7 [c]
         + $wage [c]
         + welevel [c]
         + disability [c]
         + ethnicity [c]
         + windex5 [c]
   by
          layer [c] > (
            VT22ethnic [s] [mean '' f5.1]
          + VT22sex [s] [mean '' f5.1]
          + VT22sexual [s] [mean '' f5.1]
          + VT22age [s] [mean '' f5.1]
          + VT22religion [s] [mean '' f5.1]
          + VT22disability [s] [mean '' f5.1]
          + VT22other [s] [mean '' f5.1]
          + any [s] [mean '' f5.1] )
          + nodiscrimination [s] [mean '' f5.1]
        + numWomen [c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Table EQ.3.1W: Discrimination and harassment (women)"
  	 "Percentage of women age 15-49 years who in the past 12 months have felt discriminated against or harassed and those who have not felt discriminated against or harassed, " + surveyname
   caption=
     "[1] MICS indicator EQ.7 - Discrimination; SDG Indicators 10.3.1 & 16.b.1".

* Ctables command in French.  
* ctables
  /vlabels variables = layer numWomen
           display = none
  /table  total [c]
         + HH6 [c]
         + HH7 [c]
         + $wage [c]
         + welevel [c]
         + disability [c]
         + ethnicity [c]
         + windex5 [c]
   by
          layer [c] > (
            VT22ethnic [s] [mean '' f5.1]
          + VT22sex [s] [mean '' f5.1]
          + VT22sexual [s] [mean '' f5.1]
          + VT22age [s] [mean '' f5.1]
          + VT22religion [s] [mean '' f5.1]
          + VT22disability [s] [mean '' f5.1]
          + VT22other [s] [mean '' f5.1]
          + any [s] [mean '' f5.1] )
          + nodiscrimination [s] [mean '' f5.1]
        + numWomen [c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tableau EQ.3.1W: Discrimination et harcèlement (femmes)"
  	 "Pourcentage de femmes âgées de 15 à 49 ans qui, au cours des 12 derniers mois, se sont sentis discriminés ou harcelées et qui ne se sont pas senties discriminés ou harcelés, " + surveyname
   caption=
     "[1] Indicateur MICS EQ.7 - Discrimination; Indicateurs ODD 10.3.1 et 16.b.1".


* Ctables command in Spanish.  
* ctables
  /vlabels variables = layer numWomen
           display = none
  /table  total [c]
         + HH6 [c]
         + HH7 [c]
         + $wage [c]
         + welevel [c]
         + disability [c]
         + ethnicity [c]
         + windex5 [c]
   by
          layer [c] > (
            VT22ethnic [s] [mean '' f5.1]
          + VT22sex [s] [mean '' f5.1]
          + VT22sexual [s] [mean '' f5.1]
          + VT22age [s] [mean '' f5.1]
          + VT22religion [s] [mean '' f5.1]
          + VT22disability [s] [mean '' f5.1]
          + VT22other [s] [mean '' f5.1]
          + any [s] [mean '' f5.1] )
          + nodiscrimination [s] [mean '' f5.1]
        + numWomen [c][count '' f5.0]
  /categories variables=all empty=exclude missing=exclude
  /slabels position=column visible = no
  /titles title=
     "Tabla EQ.3.1W: Discriminación y acoso (mujeres)"
  	 "Porcentaje de mujeres de 15- 49 años de edad  que en los últimos 12 meses se han sentido discriminadas o acosadas y aquellas que no se han sentido discriminadas ni acosadas, " + surveyname
   caption=
     "[1] MICS indicador EQ.7 - Discriminación; Indicadores ODS 10.3.1 y 16.b.1".

new file.
