﻿* Encoding: windows-1252.
 * The overall life satisfaction score is the average of responses to LS2. Higher scores indicate higher satisfaction levels.

 * Happiness: Women who are very or somewhat happy (LS1=1 or 2).

 * The syntax produces a working table that presents the weighted frequencies of single ladder steps. While the standard format of this table has three clusters of 
 ladder steps, i.e.0-3, 4-6 and 7-10, the working table should be investigated, to evaluate if any cluster of steps would be valuable to split, e.g. the final table presenting 0-3, 4, 5, 6, 8-10.

***.
include "surveyname.sps".

get file="wm.sav".

include "CommonVarsWM.sps".

select if (WM17 = 1).

* Weight the data by the women weight.
weight by wmweight.

* Generate total variable.
compute numWomen = 1.
variable labels numWomen "Number of women age 15-49 years".

*Ladder score. 
recode LS2 (0 thru 3 =1) (4 thru 6=2) (7 thru 10=3) (99=99) into ladder. 
variable labels ladder "Ladder step reported:" .
value labels ladder 1 "0-3" 2 "4-6" 3 "7-10" 99 "Missing".

recode LS2 (99 = sysmis) (else = copy) into averageladder .
variable labels averageladder "Average life satisfaction score [3]".

compute happy=0.
if LS1<=2 happy=100.
variable labels happy "Percentage of women who are very or somewhat happy [4]".


do if (wage <=2).
+compute numWomen1524 = 1.
+variable labels numWomen1524 "Number of women age 15-24 years".
+recode LS2 (0 thru 3 =1) (4 thru 6=2) (7 thru 10=3) (99=99) into ladder1524. 
+variable labels ladder1524 "Ladder step reported:" .
+value labels ladder1524 1 "0-3" 2 "4-6" 3 "7-10" 99 "Missing".
+recode LS2 (99 = sysmis) (else = copy) into averageladder1524 .
+variable labels averageladder1524 "Average life satisfaction score [1]".
+compute happy1524=0.
+if LS1<=2 happy1524=100.
+variable labels happy1524 "Percentage of women who are very or somewhat happy [2]".
end if.

compute total = 1.
variable labels total "".
value labels total 1 "Total".

*  For labels in French uncomment commands below.
* variable labels
	numWomen "Nombre de femmes âgées de 15-49 ans"
	/numWomen1524 "Nombre de femmes âgées de 15-24 ans"
	/ladder "Échelle d'étape signalée:"
	/averageladder "Score moyen de satisfaction à la vie [3]"
	/happy "Pourcentage de femmes qui sont très ou plutôt heureuses [4]"
	/ladder1524 "Échelle d'étape signalée:"
	/averageladder1524 "Score moyen de satisfaction à la vie [1]"
	/happy1524 "Pourcentage de femmes qui sont très ou plutôt heureuses [2]".	
* value labels 
	ladder 1 "0-3" 2 "4-6" 3 "7-10" 99 "Manquant"
	/ladder1524 1 "0-3" 2 "4-6" 3 "7-10" 99 "Manquant".
	
*  For labels in Spanish uncomment commands below.
* variable labels
	numWomen "Número de mujeres de 15-49 años"
	/numWomen1524 "Número de mujeres de 15-24 años"
	/ladder "Peldaño de la escalera reportado:"
	/averageladder "Calificación media de satisfacción con la vida [3]"
	/happy "Porcentaje de mujeres que están muy o algo felices [4]"
	/ladder1524 "Peldaño de la escalera reportado:
	/averageladder1524 "Calificación media de satisfacción con la vida [1]"
	/happy1524 "Porcentaje de mujeres que están muy o algo felices [2]".	
* value labels 
	ladder 1 "0-3" 2 "4-6" 3 "7-10" 99 "Ignorado"
	/ladder1524 1 "0-3" 2 "4-6" 3 "7-10" 99 "Ignorado".

* Ctables command in English (currently active, comment it out if using different language).
ctables
  /vlabels variables =  total 
         display = none
  /format missing = "na" 
  /table   total [c]
         + HH6 [c]
         + HH7 [c]
         + $wage [c]
         + welevel [c]
         + mstatus2 [c]
         + disability [c]
         + ethnicity [c]
         + windex5 [c]
     by
           ladder1524 [c] [rowpct.validn '' f5.1]
        + averageladder1524 [s] [mean '' f5.1]
        + happy1524 [s] [mean '' f5.1]
        + numWomen1524 [s] [sum, '', f5.0]
        +  ladder [c] [rowpct.totaln '' f5.1]
        + averageladder [s] [mean '' f5.1]
        + happy [s] [mean '' f5.1]
        + numWomen [s] [sum, '', f5.0]
  /categories variables=all empty=exclude missing=exclude
  /categories variables=ladder1524 ladder  total=yes position= after label= "Total"
  /slabels position=column visible = no
  /titles title=
     "Table EQ.4.1W: Overall life satisfaction and happiness (women)"
     "Percentage of women age 15-49 years by level of overall life satisfaction, average life satisfaction score, and the percentage who are very or somewhat satisfied with their life overall, " + surveyname
   caption=
 "[1] MICS Indicator EQ.9a - Life satisfaction among women age 15-24" 
 "[2] MICS Indicator EQ.9b - Life satisfaction among women age 15-49" 
 "[3] MICS indicator EQ.10a - Happiness among women age 15-24" 
 "[4] MICS indicator EQ.10b - Happiness among women age 15-49"
 "na: not applicable".


* Ctables command in French.  
* ctables
ctables
  /vlabels variables =  total 
         display = none
  /format missing = "na" 
  /table   total [c]
         + HH6 [c]
         + HH7 [c]
         + $wage [c]
         + welevel [c]
         + mstatus2 [c]
         + disability [c]
         + ethnicity [c]
         + windex5 [c]
     by
           ladder1524 [c] [rowpct.validn '' f5.1]
        + averageladder1524 [s] [mean '' f5.1]
        + happy1524 [s] [mean '' f5.1]
        + numWomen1524 [s] [sum, '', f5.0]
        +  ladder [c] [rowpct.totaln '' f5.1]
        + averageladder [s] [mean '' f5.1]
        + happy [s] [mean '' f5.1]
        + numWomen [s] [sum, '', f5.0]
  /categories variables=all empty=exclude missing=exclude
  /categories variables=ladder1524 ladder  total=yes position= after label= "Total"
  /slabels position=column visible = no
  /titles title=
     "Tableau EQ.4.1W: Satisfaction globale de la vie et bonheur (femmes)"
     "Pourcentage de femmes de 15 à 49 ans qui sont très ou assez satisfaites de leur vie en général, échelon signalé et score moyen de satisfaction à l'égard de la vie, " + surveyname
   caption=
 "[1] Indicateur MICS EQ.9a - Satisfaction de vie des femmes de 15 à 24 ans" 
 "[2] Indicateur MICS EQ.9b - Satisfaction de vie des femmes de 15 à 49 ans" 
 "[3] Indicateur MICS EQ.10a - Le bonheur chez les femmes de 15-24 ans" 
 "[4] Indicateur MICS EQ.10b - Le bonheur chez les femmes de 15-49 ans"
 "na: n'est pas applicable".

 
 * Ctables command in Spanish.  
* ctables
ctables
  /vlabels variables =  total 
         display = none
  /format missing = "na" 
  /table   total [c]
         + HH6 [c]
         + HH7 [c]
         + $wage [c]
         + welevel [c]
         + mstatus2 [c]
         + disability [c]
         + ethnicity [c]
         + windex5 [c]
     by
           ladder1524 [c] [rowpct.validn '' f5.1]
        + averageladder1524 [s] [mean '' f5.1]
        + happy1524 [s] [mean '' f5.1]
        + numWomen1524 [s] [sum, '', f5.0]
        +  ladder [c] [rowpct.totaln '' f5.1]
        + averageladder [s] [mean '' f5.1]
        + happy [s] [mean '' f5.1]
        + numWomen [s] [sum, '', f5.0]
  /categories variables=all empty=exclude missing=exclude
  /categories variables=ladder1524 ladder  total=yes position= after label= "Total"
  /slabels position=column visible = no
  /titles title=
     "Tabla EQ.4.1W: Satisfacción con la vida en general y la felicidad (mujeres)"
     "Porcentaje de mujeres de 15-49 años de edad por nivel de satisfacción general, puntaje promedio de satisfacción con la vida y el porcentaje que está muy o algo satisfecho con su vida en general, " + surveyname
   caption=
 "[1] MICS Indicador EQ.9a - Satisfacción con la vida entre mujeres de 15-24 años de edad" 
 "[2] MICS Indicador EQ.9b - Satisfacción con la vida entre mujeres de 15-49 años de edad" 
 "[3] MICS indicador EQ.10a - Felicidad entre mujeres de 15-24 años de edad" 
 "[4] MICS indicador EQ.10b - Felicidad entre mujeres de 15-49 años de edad"
 "na: no aplicable".

new file.
